@@ -17,7 +17,6 @@
 ;; symbol means decode with MIME encoding only.
 
 (defvar mew-dinfo-list '("limit" "decode-text" "decode-binary" "use-alt"))
-;; decode-text = t | no-cs-conv | no-cs-ld-conv
 
 (mew-blinfo-defun 'mew-dinfo mew-dinfo-list)
 
@@ -436,7 +435,7 @@ Return a part syntax after moving the beginning of the content body."
 	    (forward-line)
 	  (mew-decode-error "No end-of-header(null line) in RFC822 message"))
 	;; the beginning of the BODY(i.e. the physical content body)
-	(if (eq (mew-dinfo-get-decode-text) t) ;; not no-cs-conv, no-cs-ld-conv
+	(if (eq (mew-dinfo-get-decode-text) t) ;; not 'no-cs-conv
 	    (mew-cs-decode-region (point) (point-max) mew-cs-autoconv))
 	(mew-syntax-set-key syntax 'message)
 	(mew-syntax-set-end syntax (1- (point)))
@@ -460,8 +459,7 @@ Return a part syntax after moving the beginning of the content body."
 	    ;; Emacs 20
 	    (setq decoded (base64-decode-region beg (point-max)))
 	  (error (setq decoded nil))) ;; Emacs 21
-	(when (and decoded linebasep
-		   (not (eq (mew-dinfo-get-decode-text) 'no-cs-ld-conv)))
+	(when (and decoded linebasep)
 	  (goto-char beg)
 	  (mew-crlf-to-lf)))
       ;; base64-decode-region may fail if garbage exists.
@@ -492,7 +490,7 @@ Return a part syntax after moving the beginning of the content body."
        (t
 	(mew-decode-error (concat mew-prog-mime-decode " does not exist")))))
     ;; charset conversion
-    (if (and textp (eq (mew-dinfo-get-decode-text) t)) ;; not no-cs-conv, no-cs-ld-conv
+    (if (and textp (eq (mew-dinfo-get-decode-text) t)) ;; not 'no-cs-conv
 	(mew-decode-charset-conv charset beg))))
 
 (defun mew-decode-charset-conv (charset beg)
@@ -926,7 +924,7 @@ Return a part syntax after moving the beginning of the content body."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2002 Mew developing team.
+;; Copyright (C) 1996-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
