@@ -14,7 +14,7 @@
 
 (defvar mew-tinfo-list
   '("header-keymap" "attach-keymap" "case" "encrypted-p" "privacy-err"
-    "encode-err" "privacy-type" "hdr-file" "field-del"))
+    "encode-err" "privacy-type" "hdr-file" "field-del" "other-frame"))
 
 (mew-blinfo-defun 'mew-tinfo mew-tinfo-list)
 
@@ -26,7 +26,7 @@
   (setq mew-draft-mode-syntax-table (make-syntax-table text-mode-syntax-table))
   (modify-syntax-entry ?% "." mew-draft-mode-syntax-table))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Draft mode
 ;;;
@@ -172,7 +172,7 @@ Moreover, '~/.mew-fib' supports aliases like;
 "
   (interactive)
   (mew-draft-set-local-variables)
-  (add-hook 'local-write-file-hooks (function mew-encode-make-backup))
+  (add-hook 'local-write-file-hooks 'mew-encode-make-backup)
   (setq major-mode 'mew-draft-mode)
   (use-local-map mew-draft-mode-map)
   (set-syntax-table mew-draft-mode-syntax-table)
@@ -191,7 +191,7 @@ Moreover, '~/.mew-fib' supports aliases like;
   ;; must be here for auto-fill
   (when auto-fill-function
     (make-local-variable 'auto-fill-function)
-    (setq auto-fill-function (function mew-draft-auto-fill)))
+    (setq auto-fill-function 'mew-draft-auto-fill))
   (setq buffer-undo-list nil))
 
 (defun mew-draft-mode-name (&optional header)
@@ -213,7 +213,7 @@ Moreover, '~/.mew-fib' supports aliases like;
       (setq mode-name (concat mode-name " " (mew-tinfo-get-case))))
     (force-mode-line-update)))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Draft subfunctions
 ;;;
@@ -237,13 +237,6 @@ Moreover, '~/.mew-fib' supports aliases like;
 	  (beginning-of-line))))
     (or ret1 ret2))) ;; if modifies, return t.
 
-(defun mew-draft-buffer-name (path)
-  (let ((regex (format "^%s\\(.*\\)$"
-		       (file-name-as-directory
-			(expand-file-name mew-mail-path)))))
-    (if (string-match regex path)
-	(concat "+" (mew-match 1 path)))))
-
 (defun mew-draft-find-and-switch (draft-path &optional switch-func)
   ;; switch-func = nil :: switch-to-buffer
   ;; switch-func = t   :: switch-to-buffer-other-window
@@ -251,22 +244,21 @@ Moreover, '~/.mew-fib' supports aliases like;
 	 (special-display-regexps nil)
 	 (same-window-buffer-names nil)
 	 (same-window-regexps nil)
-	 (draftname (mew-draft-buffer-name draft-path)))
+	 (draftname (mew-path-to-folder draft-path)))
     (when (get-buffer draftname)
       (save-excursion
 	(set-buffer draftname)
 	(clear-visited-file-modtime)
 	(set-buffer-modified-p nil) ;; just in case
-	(if (file-exists-p buffer-auto-save-file-name)
-	    (delete-file buffer-auto-save-file-name))
+	(mew-delete-file buffer-auto-save-file-name)
 	(mew-remove-buffer draftname)))
     (cond
-     (mew-use-other-frame
-      (setq switch-func (function switch-to-buffer-other-frame)))
+     (mew-use-other-frame-for-draft
+      (setq switch-func 'switch-to-buffer-other-frame))
      ((eq switch-func nil)
-      (setq switch-func (function switch-to-buffer)))
+      (setq switch-func 'switch-to-buffer))
      ((eq switch-func t)
-      (setq switch-func (function switch-to-buffer-other-window))))
+      (setq switch-func 'switch-to-buffer-other-window)))
     (mew-frwlet
      mew-cs-m17n mew-cs-dummy
      (funcall switch-func (find-file-noselect draft-path)))
@@ -274,12 +266,15 @@ Moreover, '~/.mew-fib' supports aliases like;
     (mew-set-buffer-cs mew-cs-m17n)
     ;; copy config, first
     (mew-tinfo-set-case mew-case-output)
+    (when mew-use-other-frame-for-draft
+      (mew-tinfo-set-other-frame t)
+      ;; to ensure to cite a message from summary frame.
+      (mew-remove-buffer (mew-buffer-message)))
     (rename-buffer draftname)))
 
 (defun mew-draft-to-attach (draft)
   "Converting draft to attach. E.g. +draft/1 -> +attach/1"
-  (concat (file-name-as-directory mew-attach-folder)
-	  (file-name-nondirectory draft)))
+  (mew-concat-folder mew-attach-folder (file-name-nondirectory draft)))
 
 (defun mew-attachdir (&optional draft)
   (mew-expand-folder (mew-draft-to-attach (or draft (buffer-name)))))
@@ -304,8 +299,7 @@ the Body: field."
   (let ((cnt 0) (beg (point)) med adr)
     (while adrs
       (setq adr (car adrs) adrs (cdr adrs))
-      (if (mew-is-my-address del adr)
-	  ()
+      (unless (mew-is-my-address del adr)
 	(if (= cnt 0)
 	    (insert adr)
 	  (insert ", " adr))
@@ -333,7 +327,7 @@ the Body: field."
       (insert "\n")
       (mew-header-fold-region beg (point) med 'use-tab))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Draft header
 ;;;
@@ -343,58 +337,58 @@ the Body: field."
 ;; cc -- string or list
 ;; nl -- one empty line under "----", which is necessary if
 ;;      attachment is prepared
-  (let ((del mew-regex-my-address-list) ;; deleting list for Cc:
+  (let ((del (unless fromme mew-regex-my-address-list)) ;; deleting list
 	case body)
     (goto-char (point-min))
-    ;; Insert To: first.
-    ;; All addresses inserted on To: are appended to del.
-    (cond
-     ((null to) (insert mew-to: " \n"))
-     ((stringp to) ;; To: inputed from the mini-buffer.
-      ;; do not check to is mine. Cc: is also string
-      ;; We believe that user never specifies the same address of To: to Cc:.
-      (insert mew-to: " " to "\n"))
-     ;; To: collected by reply
-     ((listp to)
-      (if fromme
-	  (mew-insert-address-list2 mew-to: to)
-	(setq del (mew-insert-address-list mew-to: to del t)))))
-    (cond
-     ((null cc) ()) ;; do nothing 
-     ((stringp cc) ;; Cc: inputed from the mini-buffer.
-      (insert mew-cc: " " cc "\n"))
-     ((listp cc) ;; Cc: collected by reply.
-      (if fromme
-	  (mew-insert-address-list2 mew-cc: cc)
+    (if newsgroups
+	(cond
+	 ((stringp newsgroups)
+	  (mew-draft-header-insert mew-newsgroups: newsgroups))
+	 ((listp newsgroups)
+	  (mew-insert-address-list2 mew-newsgroups: newsgroups)))
+      ;; Insert To: first.
+      ;; All addresses inserted on To: are appended to del.
+      (cond
+       ((null to) (mew-draft-header-insert mew-to: ""))
+       ((stringp to) ;; To: inputed from the mini-buffer.
+	;; do not check to is mine. Cc: is also string
+	;; We believe that user never specifies the same address of To: to Cc:.
+	(mew-draft-header-insert mew-to: to))
+       ;; To: collected by reply
+       ((listp to)
+	(setq del (mew-insert-address-list mew-to: to del t))))
+      (cond
+       ((null cc) ()) ;; do nothing 
+       ((stringp cc) ;; Cc: inputed from the mini-buffer.
+	(mew-draft-header-insert mew-cc: cc))
+       ((listp cc) ;; Cc: collected by reply.
 	(mew-insert-address-list mew-cc: cc del nil))))
-    (mew-draft-header-insert mew-newsgroups:  newsgroups)
     (if mew-case-guess-when-prepared
 	(mew-draft-set-case-by-guess))
     (setq case (mew-tinfo-get-case))
-    (mew-draft-header-insert mew-cc:          (mew-cc case))
-    (mew-draft-header-insert mew-subj:        (or subject ""))
-    (mew-draft-header-insert mew-from:        (mew-from case))
-    (mew-draft-header-insert mew-fcc:         (mew-fcc case))
-    (mew-draft-header-insert mew-dcc:         (mew-dcc case))
-    (mew-draft-header-insert mew-reply-to:    (mew-reply-to case))
-    (mew-draft-header-insert mew-in-reply-to: in-reply-to)
-    (mew-draft-header-insert mew-references:  references)
+    (unless newsgroups
+      (mew-draft-header-insert mew-cc: (mew-cc case)))
+    (mew-draft-header-insert mew-subj: (or subject ""))
+    (mew-draft-header-insert mew-from: (mew-from case))
+    (mew-draft-header-insert mew-fcc: (mew-fcc case))
+    (unless newsgroups
+      (mew-draft-header-insert mew-dcc: (mew-dcc case)))
+    (mew-draft-header-insert mew-reply-to: (mew-reply-to case))
+    (unless newsgroups
+      (mew-draft-header-insert mew-in-reply-to: in-reply-to))
+    (mew-draft-header-insert mew-references: references)
     (if (and mew-x-face-file
 	     (file-exists-p (expand-file-name mew-x-face-file)))
-	(let ((buf (generate-new-buffer mew-buffer-prefix))
-	      xface)
-	  (save-excursion
-	    (set-buffer buf)
-	    (mew-erase-buffer)
+	(let (xface)
+	  (with-temp-buffer
 	    (insert-file-contents (expand-file-name mew-x-face-file))
 	    (setq xface (mew-buffer-substring (point-min)
 					      (max (buffer-size) 1))))
-	  (mew-remove-buffer buf)
 	  (mew-draft-header-insert mew-x-face: xface)))
     (mew-draft-header-insert mew-organization: (mew-organization case))
     (setq body (mew-draft-header-insert-alist other-headers))
     ;; Deleting fields defined in mew-header-alist to replace them.
-    (mew-header-delete-lines (mapcar (function car) (mew-header-alist case)))
+    (mew-header-delete-lines (mapcar 'car (mew-header-alist case)))
     (mew-header-goto-end)
     (mew-draft-header-insert-alist (mew-header-alist case))
     ;; X-Mailer: must be the last
@@ -405,7 +399,7 @@ the Body: field."
     (if body (save-excursion (insert body)))
     ;; move the cursor after "To: "
     (goto-char (point-min))
-    (forward-char 4))) ;; do not use (end-of-line) since the value may exist.
+    (search-forward ": " nil t)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -438,6 +432,11 @@ citation prefix and label.
       (message "Cannot cite a message here")
     (let (cite beg end)
       (save-excursion
+	(cond
+	 ((get-buffer (mew-buffer-message))
+	  (set-buffer (mew-buffer-message)))
+	 ((get-buffer mew-message-last-buffer)
+	  (set-buffer mew-message-last-buffer)))
 	(set-buffer (mew-buffer-message))
 	(save-restriction
 	  (widen)
@@ -462,6 +461,8 @@ citation prefix and label.
   "This value is used by mew-gnus.el to specify a buffer from where
 you can cite.")
 
+(defvar mew-message-citation-frame-id nil)
+
 (defun mew-draft-cite (&optional arg force)
   "Copy and paste a part of message from Message mode with
 citation prefix and label.
@@ -476,16 +477,20 @@ citation prefix and label.
   (interactive "P")
   (if (and (not force) (or (mew-in-header-p) (mew-in-attach-p)))
       (message "Cannot cite a message here")
-    (let ((nonmewbuf mew-message-citation-buffer) ;; buffer local, so copy here
-	  (fld (mew-current-get-fld (mew-frame-id)))
-	  (msg (mew-current-get-msg (mew-frame-id)))
-	  cite beg end tbuf irt-msgid)
+    (let* ((nonmewbuf mew-message-citation-buffer) ;; may be buffer local
+	   (fid (or mew-message-citation-frame-id (mew-frame-id))) 
+	   (fld (mew-current-get-fld fid))
+	   (msg (mew-current-get-msg fid))
+	   (msg-buf (mew-buffer-message))
+	   cite beg end tbuf irt-msgid)
+      (unless (get-buffer msg-buf)
+	(setq msg-buf mew-message-last-buffer))
       (save-excursion
 	;;
 	;; extract the body without header
 	;;
-	(setq tbuf (or nonmewbuf (mew-buffer-message)))
-	(if tbuf
+	(setq tbuf (or nonmewbuf msg-buf))
+	(if (get-buffer tbuf)
 	    (set-buffer tbuf)
 	  (error "No buffer to be cited"))
 	(save-restriction
@@ -509,11 +514,11 @@ citation prefix and label.
 	;; see also mew-summary-reply
 	(setq tbuf (or nonmewbuf
 		       (save-excursion
-			 (set-buffer (mew-buffer-message))
-			 (if (mew-header-p) (current-buffer)))
+			 (when (get-buffer msg-buf)
+			   (if (mew-header-p) (current-buffer))))
 		       ;; header exists only in cache if multipart
 		       (mew-cache-hit fld msg)))
-	(if tbuf
+	(if (get-buffer tbuf)
 	    (set-buffer tbuf)
 	  (error "No buffer to be cited"))
 	(save-restriction
@@ -534,7 +539,7 @@ citation prefix and label.
               (when irt
                 (setq rb irt)
                 (while (string-match "<[^>]+>" rb)
-                  (setq irtl (cons (mew-match 0 rb) irtl)) 
+                  (setq irtl (cons (match-string 0 rb) irtl)) 
                   (setq rb (substring rb (match-end 0))))
                 (if (member irt-msgid irtl)
                     (setq irt-msgid nil)))
@@ -601,18 +606,15 @@ citation prefix and label.
 'mew-cite-format' and 'mew-cite-fields'."
   (if (null mew-cite-fields)
       ""
-    (let* ((vals (mapcar (function mew-cite-get-value) mew-cite-fields))
-	   (label (apply (function format) mew-cite-format vals))
+    (let* ((vals (mapcar 'mew-cite-get-value mew-cite-fields))
+	   (label (apply 'format mew-cite-format vals))
 	   (ellipses (if (stringp mew-draft-cite-ellipses)
 			 mew-draft-cite-ellipses ""))
-	   buf beg eol str)
+	   beg eol)
       (if (not (or (eq mew-draft-cite-fill-mode 'truncate)
 		   (eq mew-draft-cite-fill-mode 'wrap)))
 	  label
-	(setq buf (generate-new-buffer mew-buffer-prefix))
-	(save-excursion
-	  (set-buffer buf)
-	  (mew-erase-buffer)
+	(with-temp-buffer
 	  (let ((fill-column
 		 (or mew-draft-cite-label-fill-column fill-column)))
 	    (insert label)
@@ -637,9 +639,7 @@ citation prefix and label.
 		  (if (= (current-column) 0) ;; for XEmacs
 		      (delete-backward-char 1)))))
 	      (forward-line)))
-	  (setq str (buffer-string)))
-	(mew-remove-buffer buf)
-	str))))
+	  (buffer-string))))))
 
 (defun mew-cite-prefix-username ()
   "A good candidate for mew-cite-prefix-function.
@@ -665,13 +665,16 @@ The citation style is 'from_address> ', e.g. 'kazu> '"
   (if (y-or-n-p "Kill draft message? ")
       (let* ((attachdir (mew-attachdir)) ;; attachdir must be here
 	     (draft (buffer-file-name))
+	     (buf (current-buffer))
 	     (mdi (concat draft mew-draft-info-suffix)))
 	(mew-overlay-delete-buffer)
 	(save-buffer)
-	(mew-remove-buffer (current-buffer))
-	(if (file-exists-p draft) (delete-file draft))
-	(if (file-exists-p mdi) (delete-file mdi))
-	(mew-current-get-window-config)
+	(mew-delete-file draft)
+	(mew-delete-file mdi)
+	(if (and (mew-tinfo-get-other-frame) (> (length (frame-list)) 1))
+	    (delete-frame)
+	  (mew-current-get-window-config))
+	(mew-remove-buffer buf)
 	(mew-delete-directory-recursively attachdir)
 	(message "Draft was killed"))
     (message "Draft was not killed")))
@@ -762,10 +765,9 @@ protected."
 Set privacy service which will be effective when \\[mew-draft-make-message]."
   (interactive)
   (let* ((services (mew-pcdb-services))
-	 (alist (mapcar (function (lambda (x) (cons (symbol-name x) x)))
-			services))
+	 (alist (mapcar (lambda (x) (cons (symbol-name x) x)) services))
 	 str)
-    (setq str (completing-read "Input privacy services : " alist nil t))
+    (setq str (completing-read "Input privacy services: " alist nil t))
     (when (stringp str)
       (mew-tinfo-set-privacy-type (cdr (assoc str alist)))
       (mew-tinfo-set-privacy-err nil)))
@@ -776,6 +778,127 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
 ;;; Sending and Queuing
 ;;;
 
+(defun mew-draft-make-message (&optional privacy signer)
+  "Compose a MIME message then put it into a queue folder."
+  (interactive)
+  (mew-draft-process-message 'queue privacy signer))
+
+(defun mew-draft-send-message ()
+  "Compose a MIME message then send it."
+  (interactive)
+  (mew-draft-process-message 'send))
+
+(defun mew-draft-process-message (action &optional privacy signer)
+  (let* ((case (or (mew-tinfo-get-case) mew-case-default))
+	 (old-case case)
+	 guessed-case)
+    (when mew-case-guess-when-composed
+      (setq guessed-case (mew-draft-get-case-by-guess))
+      (when guessed-case
+	(if mew-case-guess-addition
+	    (setq case (mew-draft-add-case case guessed-case))
+	  (setq case guessed-case))))
+    (unless (string= old-case case)
+      (mew-tinfo-set-case case)
+      (mew-draft-mode-name (mew-tinfo-get-hdr-file))
+      (mew-draft-replace-fields old-case)
+      (when (eq action 'send)
+	(mew-highlight-header)
+	(unless (mew-tinfo-get-hdr-file) (mew-draft-header-keymap)))
+      (save-buffer))
+    (if (mew-header-existp mew-newsgroups:)
+	(mew-draft-nntp-process-message case action privacy signer)
+      (mew-draft-smtp-process-message case action privacy signer))))
+
+(defun mew-draft-resent-p (end)
+  (let ((case-fold-search t))
+    (save-excursion
+      (re-search-forward mew-resent-regex end t))))
+
+(defun mew-draft-smtp-process-message (case action &optional privacy signer)
+  (run-hooks 'mew-send-hook)
+  (let* ((buf (current-buffer))
+	 (pnm (mew-smtp-info-name case))
+	 resentp fcc sendit err)
+    (if (get-process pnm)
+	(message "Another message is being sent. Try later")
+      (mew-draft-remove-illegal-fields)
+      ;; Check resentp
+      (save-excursion
+	(goto-char (point-min))
+	(setq resentp (mew-draft-resent-p (mew-header-end))))
+      ;; Ask Subject: before the query of "Really send".
+      ;; Typing C-g here gets back to the draft.
+      (mew-encode-ask-subject)
+      (setq fcc (mew-encode-ask-fcc resentp))
+      (if (eq action 'queue)
+	  (setq sendit t)
+	(if mew-ask-send
+	    (setq sendit (y-or-n-p "Really send this message? "))
+	  (setq sendit t)))
+      (when sendit
+	(if (and (mew-tinfo-get-other-frame) (> (length (frame-list)) 1))
+	    (delete-frame)
+	  (mew-current-get-window-config)
+	  (delete-windows-on buf)) ;; just in case
+	(save-excursion
+	  (save-window-excursion
+	    (set-buffer buf)
+	    (if (mew-smtp-encode pnm case resentp fcc privacy signer)
+		(let ((mdi (concat (buffer-file-name) mew-draft-info-suffix)))
+		  (mew-delete-file mdi)
+		  (cond
+		   ((eq action 'queue)
+		    (mew-smtp-queue case "from Draft mode"))
+		   ((eq action 'send)
+		    (mew-smtp-send-message case))))
+	      (setq err t))))
+	(if (not err)
+	    (run-hooks 'mew-real-send-hook)
+	  (mew-current-set-window-config)
+	  (switch-to-buffer buf)
+	  (delete-other-windows))))))
+
+(defun mew-draft-nntp-process-message (case action &optional privacy signer)
+  (run-hooks 'mew-post-hook)
+  (let* ((buf (current-buffer))
+	 (pnm (mew-nntp2-info-name case))
+	 fcc sendit err)
+    (if (get-process pnm)
+	(message "Another message is being posted. Try later")
+      (mew-draft-remove-illegal-fields)
+      ;; Ask Subject: before the query of "Really post".
+      ;; Typing C-g here gets back to the draft.
+      (mew-encode-ask-subject)
+      (setq fcc (mew-encode-ask-fcc nil))
+      (if (eq action 'queue)
+	  (setq sendit t)
+	(if mew-ask-post
+	    (setq sendit (y-or-n-p "Really post this message? "))
+	  (setq sendit t)))
+      (when sendit
+	(if (and (mew-tinfo-get-other-frame) (> (length (frame-list)) 1))
+	    (delete-frame)
+	  (mew-current-get-window-config)
+	  (delete-windows-on buf)) ;; just in case
+	(save-excursion
+	  (save-window-excursion
+	    (set-buffer buf)
+	    (if (mew-nntp2-encode pnm case fcc privacy signer)
+		(let ((mdi (concat (buffer-file-name) mew-draft-info-suffix)))
+		  (mew-delete-file mdi)
+		  (cond
+		   ((eq action 'queue)
+		    (mew-nntp2-queue case "from Draft mode"))
+		   ((eq action 'send)
+		    (mew-nntp2-send-message case))))
+	      (setq err t))))
+	(if (not err)
+	    (run-hooks 'mew-real-post-hook)
+	  (mew-current-set-window-config)
+	  (switch-to-buffer buf)
+	  (delete-other-windows))))))
+
 (defun mew-draft-remove-illegal-fields ()
   (when (mew-header-end)
     (save-excursion
@@ -799,94 +922,12 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
 	       (setq med (match-end 0))
 	       (forward-line)
 	       (mew-header-goto-next)
-	       (setq str (buffer-substring med (1- (point))))
+	       (setq str (mew-buffer-substring med (1- (point))))
 	       ;; str may consists of multiple lines
 	       ;; So, "$" does not work. We need to use "[^ ]".
 	       (unless (string-match "[^ \t\n]" str)
 		 (delete-region beg (point)))))))))))
 
-(defun mew-draft-resent-p (end)
-  (let ((case-fold-search t))
-    (save-excursion
-      (re-search-forward mew-resent-regex end t))))
-
-(defun mew-draft-process-message (action &optional privacy signer)
-  (let* ((buf (current-buffer))
-	 (case (mew-tinfo-get-case))
-	 (old-case case)
-	 resentp fcc guessed-case server ssh-server pnm sendit err)
-    (run-hooks 'mew-send-hook)
-    (when mew-case-guess-when-composed
-      (setq guessed-case (mew-draft-get-case-by-guess))
-      (when guessed-case
-	(if mew-case-guess-addition
-	    (setq case (mew-draft-add-case case guessed-case))
-	  (setq case guessed-case))))
-    (setq server (mew-smtp-server case))
-    (setq ssh-server (mew-smtp-ssh-server case))
-    (setq pnm (mew-smtp-info-name case))
-    (if (mew-smtp-get-lock pnm)
-	(message "Another message is being sent. Try later")
-      (mew-draft-remove-illegal-fields)
-      (unless (string= old-case case)
-	(mew-tinfo-set-case case)
-	(mew-draft-mode-name (mew-tinfo-get-hdr-file))
-	(mew-draft-replace-fields old-case)
-	(when (eq action 'send)
-	  (mew-highlight-header)
-	  (unless (mew-tinfo-get-hdr-file) (mew-draft-header-keymap)))
-	(save-buffer))
-      ;; Check resentp
-      (save-excursion
-	(goto-char (point-min))
-	(setq resentp (mew-draft-resent-p (mew-header-end))))
-      ;; Ask Subject: before the query of "Really send".
-      ;; Typing C-g here gets back to the draft.
-      (mew-encode-ask-subject)
-      (setq fcc (mew-encode-ask-fcc resentp))
-      (mew-encode-ask-newsgroups)
-      (if (eq action 'queue)
-	  (setq sendit t)
-	(if mew-ask-send
-	    (setq sendit (y-or-n-p "Really send this message? "))
-	  (setq sendit t)))
-      (when sendit
-	(mew-smtp-set-case pnm case)
-	(mew-smtp-set-server pnm server)
-	(mew-smtp-set-port pnm (mew-smtp-port case))
-	(mew-smtp-set-ssh-server pnm ssh-server)
-	(mew-smtp-set-queue pnm (mew-queue-folder case))
-	(mew-smtp-set-fcc pnm fcc)
-	(mew-current-get-window-config)
-	(delete-windows-on buf) ;; just in case
-	(save-excursion
-	  (save-window-excursion
-	    (set-buffer buf)
-	    (if (mew-encode pnm case resentp privacy signer)
-		(let ((mdi (concat (buffer-file-name) mew-draft-info-suffix)))
-		  (if (file-exists-p mdi) (delete-file mdi))
-		  (cond
-		   ((eq action 'queue)
-		    (mew-smtp-queue pnm "from Draft mode"))
-		   ((eq action 'send)
-		    (mew-smtp-send-message pnm))))
-	      (setq err t)))))
-      (if (not err)
-	  (run-hooks 'mew-real-send-hook)
-	(mew-current-set-window-config)
-	(switch-to-buffer buf)
-	(delete-other-windows)))))
-
-(defun mew-draft-make-message (&optional privacy signer)
-  "Compose a MIME message then put it into a queue folder."
-  (interactive)
-  (mew-draft-process-message 'queue privacy signer))
-
-(defun mew-draft-send-message ()
-  "Compose a MIME message then send it."
-  (interactive)
-  (mew-draft-process-message 'send))
-
 ;; backward-compatibility
 (defalias 'mew-draft-send-letter 'mew-draft-send-message)
 
@@ -894,7 +935,7 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2002 Mew developing team.
+;; Copyright (C) 1996-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
