@@ -19,6 +19,11 @@ requires PTY.")
 (defvar mew-connection-type2 t
   "Connection type for processes that requires a password. ")
 
+(defvar mew-connection-type-for-scan t
+  "Connection type for 'mewls' whose output speed is very fast. 
+To slow down, PTY should be used.")
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Must be here for key setup
 ;;;
@@ -30,6 +35,7 @@ requires PTY.")
   (defalias 'mew-set-keymap-parent 'set-keymap-parent)))
 
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Emacsen
 ;;;
@@ -40,9 +46,12 @@ requires PTY.")
 (defvar mew-mule-p   nil)
 (defvar mew-icon-p   nil)
 (defvar mew-mule-ver 0)
+(defvar mew-internal-utf-8p nil)
 
 (if (featurep 'mule) (setq mew-mule-p t))
 
+(require 'easymenu) ;; to prepend the loading messages
+(require 'pp) ;; to prevent the loading messages
 (cond
  ((featurep 'xemacs)
   (setq mew-temacs-p nil)
@@ -65,10 +74,16 @@ requires PTY.")
       (require 'mew-temacs)
     (if (eq window-system 'x) (setq mew-icon-p t))
     (setq mew-gemacs-p t)
-    (require 'mew-gemacs))
+    (require 'image) ;; to prepend the loading messages
+    (require 'jit-lock) ;; to prepend the loading messages
+    (require 'regexp-opt) ;; to prepend the loading messages
+    (require 'mew-gemacs)
+    (if (>= emacs-minor-version 3) ;; Emacs 21.3
+	(setq mew-internal-utf-8p t)))
   (setq mew-mule-ver 3)
   (require 'mew-mule3)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Emacs vs XEmacs
 ;;;
@@ -84,7 +99,8 @@ requires PTY.")
   ;;
   (add-hook 'pre-idle-hook 'mew-summary-cook-window)
   ;;
-  (defalias 'mew-md5 'md5))
+  (defun mew-md5 (str)
+    (md5 str nil nil 'binary)))
  ;;
  (mew-temacs-p
   (if window-system (require 'faces))
@@ -93,13 +109,20 @@ requires PTY.")
   ;;
   (defsubst mew-mark () (marker-position (mark-marker)))
   ;;
-  (require 'mew-md5)))
+  (if (string< emacs-version "21")
+      (require 'mew-md5)
+    (defun mew-md5 (str)
+      (md5 str nil nil 'binary)))))
 
+(if mew-xemacs-p
+    (defalias 'mew-window-edges 'window-pixel-edges)
+  (defalias 'mew-window-edges 'window-edges))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Misc
 ;;;
 
-;; xxx
 (defun mew-timer (sec func) (run-at-time sec sec func))
 
 (if (fboundp 'characterp)
@@ -110,11 +133,21 @@ requires PTY.")
     (defalias 'mew-mouse-region-p 'mouse-region-match)
   (defsubst mew-mouse-region-p () nil))
 
-(if (boundp 'automatic-hscrolling)
-    (defsubst mew-hscroll ()
-      (set (make-local-variable 'automatic-hscrolling) t))
-  (defsubst mew-hscroll () (auto-show-mode 1)))
+(cond
+ ((boundp 'auto-hscroll-mode) ;; Emacs 21.3 or later
+  (defsubst mew-hscroll ()
+    (set (make-local-variable 'auto-hscroll-mode) t)))
+ ((boundp 'automatic-hscrolling) ;; Emacs 21.2 or earlier
+  (defsubst mew-hscroll ()
+    (set (make-local-variable 'automatic-hscrolling) t)))
+ (t
+  (defsubst mew-hscroll () (auto-show-mode 1))))
 
+(if (fboundp 'minibuffer-prompt-end)
+    (defalias 'mew-minibuf-point-min 'minibuffer-prompt-end)
+  (defalias 'mew-minibuf-point-min 'point-min))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Sticky
 ;;;
@@ -154,6 +187,7 @@ requires PTY.")
 (defsubst mew-rear-nonsticky (beg end)
   (put-text-property beg end mew-rn mew-rnv))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Overlay
 ;;;
@@ -168,7 +202,7 @@ requires PTY.")
 
 (defsubst mew-overlay-delete-region (beg end)
   (interactive "r")
-  (mapcar (function mew-overlay-delete) (overlays-in beg end))
+  (mapcar 'mew-overlay-delete (overlays-in beg end))
   (if (fboundp 'remove-images) (remove-images beg end))) ;; xxx
 
 (defsubst mew-overlay-delete-buffer ()
@@ -176,6 +210,20 @@ requires PTY.")
     (widen)
     (mew-overlay-delete-region (point-min) (point-max))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; File operations
+;;;
+
+(if (or mew-xemacs-p mew-gemacs-p)
+    (defalias 'mew-face-spec-set 'face-spec-set)
+  ;; face-spec-set on Emacs 20.7 does not effect new frames.
+  (defun mew-face-spec-set (face spec)
+    "Set FACE's attributes according to the first matching entry in SPEC
+on all frames."
+    (custom-set-faces `(,face ,spec))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; File operations
 ;;;
@@ -184,29 +232,48 @@ requires PTY.")
  ((fboundp 'make-symbolic-link)
   (defsubst mew-symbolic-link (filename newname &optional OK-IF-ALREADY-EXISTS)
     (if (file-directory-p (file-chase-links filename))
-	(error "Can't make a symbolic link to directory")
+	(error "Cannot make a symbolic link to directory")
       (make-symbolic-link filename newname OK-IF-ALREADY-EXISTS)))
   (defsubst mew-link (filename newname &optional OK-IF-ALREADY-EXISTS)
     (if (file-directory-p (file-chase-links filename))
-	(error "Can't make a link to directory")
-      (add-name-to-file filename newname OK-IF-ALREADY-EXISTS))))
+	(error "Cannot make a link to directory")
+      (condition-case nil
+	  (add-name-to-file filename newname OK-IF-ALREADY-EXISTS)
+	(file-error
+	 (copy-file filename newname OK-IF-ALREADY-EXISTS 'keepdate))))))
  (t
   (defsubst mew-symbolic-link (filename newname &optional OK-IF-ALREADY-EXISTS)
     (if (file-directory-p filename)
-	(error "Can't make a copy of directory")
+	(error "Cannot make a copy of directory")
       (copy-file filename newname OK-IF-ALREADY-EXISTS 'keepdate)))
   (defsubst mew-link (filename newname &optional OK-IF-ALREADY-EXISTS)
     (if (file-directory-p filename)
-	(error "Can't make a copy of directory")
+	(error "Cannot make a copy of directory")
       (copy-file filename newname OK-IF-ALREADY-EXISTS 'keepdate)))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Property
+;;;
+
+(defalias 'mew-buffer-substring 'buffer-substring-no-properties)
+
+(if (fboundp 'match-string-no-properties)
+    (defalias 'mew-match-string 'match-string-no-properties)
+  (defalias 'mew-match-string 'match-string))
+
+(defsubst mew-insert-buffer-substring (buf beg end)
+  (insert (save-excursion (set-buffer buf) (mew-buffer-substring beg end))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Base64
 ;;;
 
 (cond
  ((fboundp 'base64-encode-string)
-  (defalias 'mew-base64-encode-string 'base64-encode-string))
+  (defun mew-base64-encode-string (str)
+    (base64-encode-string str 'no-line-break)))
  (t
   (defconst mew-base64-char64
     "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/")
@@ -270,7 +337,7 @@ requires PTY.")
 	    (not (zerop (logand len 3)))
 	    (< padlen 0)
 	    (> padlen 2))
-	nil);; return value
+	nil) ;; return value
        ((zerop (setq len (- len padlen))) "")
        (t
 	(setq ret (make-string (/ (* len 3) 4) ?a))
@@ -292,11 +359,21 @@ requires PTY.")
 	    (aset ret (1+ (1+ j)) (logand c 255)))
 	ret))))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Language
+;;;
+
+;; to load the thread separator
+(if (and (boundp 'current-language-environment)
+	 (string= current-language-environment "Japanese"))
+    (require 'mew-lang-jp))
+
 (provide 'mew-env)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2001 Mew developing team.
+;; Copyright (C) 1997-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
