@@ -97,13 +97,23 @@ DELS represents the messages to be deleted."
 ;;; Unlinking, moving, to-trash
 ;;;
 
+(defun mew-folder-suffix (folder)
+  (if (or (mew-folder-queuep folder) (mew-folder-postqp folder))
+      mew-queue-info-suffix
+    (if (mew-folder-draftp folder)
+	mew-draft-info-suffix)))
+
 (defun mew-summary-unlink-msgs (src dels)
-  (let (file)
+  (let ((suffix (mew-folder-suffix src))
+	file infofile)
     (while dels
       (setq file (mew-expand-folder src (car dels)))
       (setq dels (cdr dels))
       ;; if file does not exist, the marked line will be deleted anyway.
-      (mew-delete-file file))))
+      (mew-delete-file file)
+      (when suffix
+	(setq infofile (concat file suffix))
+	(mew-delete-file infofile)))))
 
 (defun mew-i2s (num cache)
   (if cache
@@ -116,7 +126,8 @@ DELS represents the messages to be deleted."
 	 (srcx (mew-folder-folder src))
 	 (myselfp (member srcx dsts))
 	 (cache mew-inherit-offline)
-	 msgs- msg srcfile dstfile dst num strnum)
+	 (suffix (mew-folder-suffix srcx))
+	 msgs- msg srcfile dstfile dst num strnum infofile)
     (if myselfp
 	;; msg stays in the src folder with the same number
 	(progn
@@ -139,7 +150,10 @@ DELS represents the messages to be deleted."
 	  (setq msgs- (cons strnum msgs-))
 	  (setq dstfile (mew-expand-folder dst strnum))
 	  (setq num (1+ num))
-	  (rename-file srcfile dstfile 'override)))
+	  (rename-file srcfile dstfile 'override)
+	  (when suffix
+	    (setq infofile (concat srcfile suffix))
+	    (mew-delete-file infofile))))
       (mew-touch-folder dst)
       (setq msgs- (nreverse msgs-))
       (setq src dst)) ;; myselfp
@@ -160,12 +174,14 @@ DELS represents the messages to be deleted."
 (defun mew-summary-totrash-msgs (src dels)
   (let* ((trash (mew-folder-case-folder mew-inherit-exec-case mew-trash-folder))
 	 (trashdir (mew-expand-folder trash))
-	 (queue-p (or (mew-folder-queuep src) (mew-folder-postqp src)))
 	 (cache mew-inherit-offline)
-	 num srcfile dstfile mqifile)
+	 (suffix (mew-folder-suffix src))
+	 num srcfile dstfile infofile)
     (unless (file-directory-p trashdir) (make-directory trashdir))
     (setq num (string-to-int (mew-folder-new-message trash 'num-only cache)))
     ;; must be here after ensuring that +trash exists.
+
+
     (while dels
       (setq srcfile (mew-expand-folder src (car dels))) ;; xxx
       (setq dels (cdr dels))
@@ -174,9 +190,9 @@ DELS represents the messages to be deleted."
       (if (file-regular-p srcfile)
 	  ;; if not, the marked line will be deleted anyway.
 	  (rename-file srcfile dstfile 'override))
-      (when queue-p
-	(setq mqifile (concat srcfile mew-queue-info-suffix))
-	(mew-delete-file mqifile)))
+      (when suffix
+	(setq infofile (concat srcfile suffix))
+	(mew-delete-file infofile)))
     (mew-touch-folder trash)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -560,7 +576,7 @@ the queue, type '\\[mew-summary-send-message]' in the queue online."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2002 Mew developing team.
+;; Copyright (C) 1997-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
