@@ -55,7 +55,7 @@
 (defsubst mew-ext-include-get-func (acc-type)
   (nth 1 (mew-assoc-case-equal acc-type mew-ext-include-switch 0)))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; environment variables
 ;;;
@@ -75,7 +75,7 @@
     (let ((efs-tmp-name-template mew-temp-file) exp)
       (setq exp (efs-expand-file-name (format "/%s@%s:%s" user host dir)))
       (if (string-match ".*:\\(.*\\)$" exp)
-	  (mew-match 1 exp))))
+	  (match-string 1 exp))))
   (defun mew-ext-copy-file-internal (remote local passwd)
     (require 'efs)
     (let ((efs-tmp-name-template mew-temp-file)
@@ -97,14 +97,14 @@
     (let ((ange-ftp-tmp-name-template mew-temp-file) exp)
       (setq exp (ange-ftp-expand-file-name (format "/%s@%s:%s" user host dir)))
       (if (string-match ".*:\\(.*\\)$" exp)
-	  (mew-match 1 exp))))
+	  (match-string 1 exp))))
   (defun mew-ext-copy-file-internal (remote local passwd)
     (require 'ange-ftp)
     (let ((ange-ftp-tmp-name-template mew-temp-file)
 	  (ange-ftp-generate-anonymous-password passwd))
       (ange-ftp-copy-file-internal remote local t nil nil nil t)))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Encode
 ;;;
@@ -142,11 +142,8 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (defun mew-ext-encode (filename)
-  (let ((buf (generate-new-buffer mew-buffer-prefix))
-	ret access-type ct name)
-    (save-excursion
-      (set-buffer buf)
-      (mew-erase-buffer)
+  (let (ret access-type ct name)
+    (with-temp-buffer
       ;;content-header
       (setq access-type (mew-input-general
 			 "Access type" mew-ext-encode-switch t 
@@ -178,7 +175,6 @@
 	(insert (read-string "Input message to the mail-server: "))
 	(insert "\n"))
       (write-file filename))
-    (mew-remove-buffer buf)
     (cons mew-ct-ext (cons (list "access-type" access-type) ret))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -188,15 +184,14 @@
   (let ((mew-ext-host (mew-input-general 
 		       "FTP server"
 		       (if mew-ext-ftp-server-list 
-			   (mapcar (function list) 
-				   mew-ext-ftp-server-list))
+			   (mapcar 'list mew-ext-ftp-server-list))
 		       nil
 		       (car mew-ext-ftp-server-list)))
 	mew-ext-user path dir file ret)
     (setq ret (list (list "site" mew-ext-host)))
     (setq mew-ext-user (read-string (format "User name at %s: " mew-ext-host)
 				    (mew-user)))
-    (setq path (mew-input-rfile "Filename :"))
+    (setq path (mew-input-rfile "Filename:"))
     (setq file (file-name-nondirectory path))
     (setq dir (file-name-directory path))
     (if (and dir (string-match mew-home dir))
@@ -223,13 +218,12 @@
 	(mew-ext-host (mew-input-general
 		       "FTP server"
 		       (if mew-ext-ftp-server-list 
-			   (mapcar (function list) 
-				   mew-ext-ftp-server-list))
+			   (mapcar 'list mew-ext-ftp-server-list))
 		       nil
 		       (car mew-ext-ftp-server-list)))
 	path dir file ret)
     (setq ret (list (list "site" mew-ext-host)))
-    (setq path (mew-input-rfile "Filename :"))
+    (setq path (mew-input-rfile "Filename:"))
     (setq file (file-name-nondirectory path))
     (setq dir (file-name-directory path))
     (if (and dir (string-match mew-home dir))
@@ -266,7 +260,7 @@
   (let ((url (read-string "URL: ")))
     (list (list "url" url))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Decode
 ;;;
@@ -298,10 +292,9 @@
 	  (size (mew-syntax-get-param params "size"))
 	  filepath)
      (if directory
-	 (setq filepath (concat (file-name-as-directory directory) name))
+	 (setq filepath (mew-concat-folder directory name))
        (setq filepath name))
-     (if (and filepath (string-match "^[A-Za-z]:/.+" filepath)) ;; drive letter
-	 (setq filepath (substring filepath 2 (match-end 0))))
+     (setq filepath (mew-remove-drive-letter filepath))
      (mew-erase-buffer)
      (insert " ####### ####### ######  \n"
 	     " #          #    #     # \n"
@@ -327,17 +320,16 @@
 	 (getit t) (username "")
 	 filepath localfile lfname remotefile)
     (if directory
-	(setq filepath (concat (file-name-as-directory directory) name))
+	(setq filepath (mew-concat-folder directory name))
       (setq filepath name))
-    (if (and filepath (string-match "^[A-Za-z]:/.+" filepath)) ;; drive letter
-	(setq filepath (substring filepath 2 (match-end 0))))
+    (setq filepath (mew-remove-drive-letter filepath))
     (setq username (read-string (format "User name at %s: " site) (mew-user)))
     (setq remotefile (format "/%s@%s:%s" username site filepath))
     (setq localfile (mew-summary-input-file-name "Save to: " name))
     (setq lfname (file-name-nondirectory localfile))
     (if (file-exists-p localfile)
 	(if (y-or-n-p (format "%s exists. Overwrite? " lfname))
-	    (delete-file localfile)
+	    (mew-delete-file localfile)
 	  (setq getit nil)
 	  (message "The file was not retrieved")))
     (if getit (mew-ext-copy-file-internal remotefile localfile nil))))
@@ -357,10 +349,9 @@
 	  (size (mew-syntax-get-param params "size"))
 	  filepath)
      (if directory
-	 (setq filepath (concat (file-name-as-directory directory) name))
+	 (setq filepath (mew-concat-folder directory name))
        (setq filepath name))
-     (if (and filepath (string-match "^[A-Za-z]:/.+" filepath)) ;; drive letter
-	 (setq filepath (substring filepath 2 (match-end 0))))
+     (setq filepath (mew-remove-drive-letter filepath))
      (mew-erase-buffer)
      (insert " Anonymous \n"
 	     " ####### ####### ######  \n"
@@ -387,10 +378,9 @@
 	 (getit t)
 	 filepath localfile lfname remotefile url)
     (if directory
-	(setq filepath (concat (file-name-as-directory directory) name))
+	(setq filepath (mew-concat-folder directory name))
       (setq filepath name))
-    (if (and filepath (string-match "^[A-Za-z]:/.+" filepath)) ;; drive letter
-	(setq filepath (substring filepath 2 (match-end 0))))
+    (setq filepath (mew-remove-drive-letter filepath))
     (setq remotefile (format "/%s@%s:%s" "anonymous" site filepath))
     (if (string-match "^[/\:]" filepath)
 	(setq url (format "ftp://%s%s" site filepath))
@@ -399,7 +389,7 @@
     (setq lfname (file-name-nondirectory localfile))
     (if (file-exists-p localfile)
 	(if (y-or-n-p (format "%s exists. Overwrite? " lfname))
-	    (delete-file localfile)
+	    (mew-delete-file localfile)
 	  (setq getit nil)
 	  (message "The file was not retrieved")))
     (when getit
@@ -504,10 +494,10 @@
      ((stringp prog)
       (setq args (append args (list url)))
       (message "Executing %s..."
-	       (mapconcat (function append) (append (list prog) args) " "))
+	       (mapconcat 'identity (append (list prog) args) " "))
       (save-excursion ;; xxx this is necessary in other places
 	(setq pnm (format "*Mew %s*" prog))
-	(apply (function start-process) pnm nil prog args)))
+	(apply 'start-process pnm nil prog args)))
      (t (message "Program list error")))))
 
 (defun mew-ext-url-show-by-w3 (dummy url)
@@ -534,7 +524,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2002 Mew developing team.
+;; Copyright (C) 1996-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
