@@ -5,7 +5,7 @@
 
 ;;; Code:
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Menu setting
 ;;;
@@ -46,19 +46,24 @@
  "Menu used in Draft mode."
  mew-draft-mode-menu-spec)
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Toolbar functions
 ;;;
 
 (defun mew-toolbar-make (alist map)
-  (let ((tool-bar-map (make-sparse-keymap))
+  (let ((tool-bar-map (make-sparse-keymap)) ;; for tool-bar-add-item-from-menu
 	(data-directory mew-icon-directory)
 	a)
     (while alist
       (setq a (car alist))
       (setq alist (cdr alist))
-      (tool-bar-add-item-from-menu (car a) (cdr a) map))
+      (if (fboundp 'tool-bar-local-item-from-menu)
+	  ;; Emacs 21.3 or later
+	  (tool-bar-local-item-from-menu (car a) (cdr a) tool-bar-map map)
+	;; Emacs 21.2 or earlier
+	;; The target map is tool-bar-map
+	(tool-bar-add-item-from-menu (car a) (cdr a) map)))
     tool-bar-map))
 
 (defun mew-summary-setup-decoration ()
@@ -81,7 +86,7 @@
 (defsubst mew-draft-toolbar-update ())
 (defsubst mew-header-toolbar-update ())
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; End of messages
 ;;;
@@ -95,12 +100,13 @@
 (defsubst mew-message-set-end-of-nil ()
   (overlay-put (mew-minfo-get-overlay) 'before-string nil))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Image
 ;;;
 
 (defun mew-image-inline-p (format)
+  ;; display-graphic-p
   (and window-system (image-type-available-p format)))
 
 (defun mew-mime-image (cache begin end format)
@@ -118,7 +124,25 @@
   (goto-char (point-min))
   (message "Loading image...done"))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; X Face
+;;;
+
+(defun mew-x-face-create ()
+  (create-image
+   (string-as-unibyte (mew-buffer-substring (point-min) (point-max)))
+   nil t))
+
+(defun mew-x-face-display (xface)
+  (save-excursion
+    (goto-char (point-min))
+    (let ((regex2 (concat "^\\(" mew-from: "\\).*")))
+      (when (re-search-forward regex2 nil t)
+	(goto-char (match-end 1))
+	(insert-image xface)))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Profile
 ;;;
@@ -134,11 +158,28 @@
       (let ((profile-buffer mew-buffer-debug))
 	(profile-results))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; SSL/SSH notification
+;;;
+
+(defvar mew-secure-format nil)
+
+;; Emacs 21.x has a bug that an image cannot be displayed 
+;; if it is specified in mode-line-process.
+
+(defvar mew-secure-format2
+  (if (display-graphic-p)
+      (let ((data-directory mew-icon-directory))
+	(concat " " (propertize "Sec" 'display
+				(find-image '((:type xpm :file "mew-lock.xpm" :ascent center))))))
+    " [Sec]"))
+
 (provide 'mew-gemacs)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2002 Mew developing team.
+;; Copyright (C) 1997-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
