@@ -249,25 +249,21 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 (defun mew-pgp-setup ()
   (cond
    ((mew-which-exec mew-prog-pgp)
-    (let ((buf (generate-new-buffer mew-buffer-prefix)))
-      (save-excursion
-	(set-buffer buf)
-	(mew-erase-buffer)
-	(mew-call-process-lang mew-prog-pgp nil t nil)
+    (with-temp-buffer
+      (mew-call-process-lang mew-prog-pgp nil t nil)
+      (goto-char (point-min))
+      (if (search-forward "PGP is now invoked" nil t)
+	  (setq mew-pgp-ver mew-pgp-ver5)
 	(goto-char (point-min))
-	(if (search-forward "PGP is now invoked" nil t)
-	    (setq mew-pgp-ver mew-pgp-ver5)
+	(if (search-forward "Pretty Good Privacy(tm) 2" nil t)
+	    (setq mew-pgp-ver mew-pgp-ver2)
 	  (goto-char (point-min))
-	  (if (search-forward "Pretty Good Privacy(tm) 2" nil t)
-	      (setq mew-pgp-ver mew-pgp-ver2)
+	  (if (search-forward "gpg" nil t)
+	      (setq mew-pgp-ver mew-pgp-verg)
 	    (goto-char (point-min))
-	    (if (search-forward "gpg" nil t)
-		(setq mew-pgp-ver mew-pgp-verg)
-	      (goto-char (point-min))
-	      (if (search-forward "Pretty Good Privacy(tm) Version 6" nil t)
-		  (setq mew-pgp-ver mew-pgp-ver6)
-		(setq mew-pgp-ver nil))))))
-      (mew-remove-buffer buf)))
+	    (if (search-forward "Pretty Good Privacy(tm) Version 6" nil t)
+		(setq mew-pgp-ver mew-pgp-ver6)
+	      (setq mew-pgp-ver nil)))))))
    (t (setq mew-pgp-ver nil))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -363,12 +359,8 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 
 (defun mew-pgp-verify (file1 file2)
   (message "PGP verifying...")
-  (let ((ioption (mew-pgp-get mew-prog-arg-input))
-	(buf (generate-new-buffer mew-buffer-prefix))
-	ret)
-    (save-excursion
-      (set-buffer buf)
-      (mew-erase-buffer)
+  (let ((ioption (mew-pgp-get mew-prog-arg-input)) ret)
+    (with-temp-buffer
       (if ioption
 	  (apply 'mew-call-process-lang
 		 (mew-pgp-get mew-prog-pgpv)
@@ -381,25 +373,19 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	       (append (mew-pgp-get mew-prog-pgpv-arg)
 		       (list file2 file1))))
       (setq ret (mew-pgp-verify-check)))
-    (mew-remove-buffer buf)
     (message "PGP verifying...done")
     ret))
 
 (defun mew-pgp-verify-old (file)
   (message "PGP verifying...")
-  (let ((buf (generate-new-buffer mew-buffer-prefix))
-	(file1 (mew-make-temp-name))
-	verify)
-    (save-excursion
-      (set-buffer buf)
-      (mew-erase-buffer)
+  (let ((file1 (mew-make-temp-name)) verify)
+    (with-temp-buffer
       (apply 'mew-call-process-lang
 	     (mew-pgp-get mew-prog-pgpv)
 	     nil t nil 
 	     (append (mew-pgp-get mew-prog-old-pgpv-arg)
 		     (list (mew-pgp-get mew-prog-arg-output) file1 file)))
       (setq verify (mew-pgp-verify-check)))
-    (mew-remove-buffer buf)
     (message "PGP verifying...done")
     (list file1 verify)))
 
@@ -425,11 +411,8 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
   (message "PGP encrypting...")
   (let ((roption (mew-pgp-get mew-prog-arg-ruserid))
 	(file2 (mew-make-temp-name))
-	(buf (generate-new-buffer mew-buffer-prefix))
 	check file3) ;; not unique if file3 is made here
-    (save-excursion
-      (set-buffer buf)
-      (mew-erase-buffer)
+    (with-temp-buffer
       (insert "Version: 1\n")
       (write-region (point-min) (point-max) file2  nil 'no-msg)
       (setq file3 (concat (mew-make-temp-name) mew-pgp-ascii-suffix))
@@ -452,10 +435,9 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	       nil t nil
 	       (mew-pgp-get mew-prog-arg-output) file3 file1 
 	       (append (mew-pgp-get mew-prog-pgpe-arg) decrypters)))
-      (setq check (mew-pgp-encrypt-check))
-      (mew-remove-buffer buf)
-      (message "PGP encrypting...done")
-      (list file2 "7bit" file3 "7bit" check)))) ;; both ctes are 7bit
+      (setq check (mew-pgp-encrypt-check)))
+    (message "PGP encrypting...done")
+    (list file2 "7bit" file3 "7bit" check))) ;; both ctes are 7bit
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -486,16 +468,13 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     (mew-rendezvous mew-pgp-running)
     (message "PGP decrypting...done")
     (if (file-exists-p file3)
-	(let ((buf (generate-new-buffer mew-buffer-prefix)))
-	  (save-excursion
-	    (set-buffer buf)
-	    (mew-erase-buffer)
+	(progn
+	  (with-temp-buffer
 	    (insert mew-pgp-string)
 	    (setq verify (mew-pgp-verify-check)))
 	  (if verify 
 	      (setq mew-pgp-decrypt-msg
-		    (concat mew-pgp-decrypt-msg "\n\t" verify)))
-	  (mew-remove-buffer buf))
+		    (concat mew-pgp-decrypt-msg "\n\t" verify))))
       ;; unpredictable error
       (mew-passwd-set-passwd (mew-pgp-passtag) nil)
       (if (string= mew-pgp-decrypt-msg mew-pgp-result-sec-succ)
@@ -508,19 +487,14 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 ;;;
 
 (defun mew-pgp-get-micalg ()
-  (let ((micalg (mew-pgp-get mew-pgp-micalg))
-	buf alg)
+  (let ((micalg (mew-pgp-get mew-pgp-micalg)) alg)
     (if (/= mew-pgp-ver mew-pgp-verg)
 	micalg
-      (setq buf (generate-new-buffer mew-buffer-prefix))
-      (save-excursion
-	(set-buffer buf)
-	(mew-erase-buffer)
+      (with-temp-buffer
 	(insert mew-pgp-string)
 	(goto-char (point-min))
 	(if (re-search-forward "SIG_CREATED [A-Z] [0-9]+ \\([0-9]+\\)" nil t)
 	   (setq alg (cdr (assoc (mew-match-string 1) mew-pgp-hash-alist)))))
-      (mew-remove-buffer buf)
       (or alg micalg))))
 
 (defun mew-pgp-sign (file1)
@@ -753,7 +727,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
      (let* ((fld (mew-summary-folder-name))
 	    (msg (mew-summary-message-number))
  	    (file (mew-expand-folder fld msg))
-	    file1 type result win start buf
+	    file1 type result win start
 	    mew-inherit-decode-signer)
        (save-excursion
 	 (set-buffer (mew-buffer-message))
@@ -763,13 +737,9 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	  (setq start (window-start win))
 	  (setq type (mew-pgp-check-old-pgp))
 	  (unless type
-	    (setq buf (generate-new-buffer mew-buffer-prefix))
-	    (save-excursion
-	      (set-buffer buf)
-	      (mew-erase-buffer)
+	    (with-temp-buffer
 	      (insert-file-contents file)
-	      (setq type (mew-pgp-check-old-pgp)))
-	    (mew-remove-buffer buf))
+	      (setq type (mew-pgp-check-old-pgp))))
 	  (if (null type)
 	      (message "No PGP message was found")
 	    (setq mew-inherit-decode-signer
@@ -815,7 +785,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	   (nums (mew-syntax-nums))
 	   (subdir (mew-attach-expand-path mew-encode-syntax nums))
 	   (attachdir (mew-attachdir))
-	   user file filepath begin end buf)
+	   user file filepath begin end)
       ;; attachdir / {subdir/} dir
       (unless (string= subdir "")
 	(setq attachdir (expand-file-name subdir attachdir)))
@@ -826,10 +796,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	(setq file (file-name-nondirectory filepath))
 	(setq user (car (mew-input-address
 			 "Who's key? (%s): " (mew-get-my-address))))
-	(setq buf (generate-new-buffer mew-buffer-prefix))
-	(save-excursion
-	  (set-buffer buf)
-	  (mew-erase-buffer)
+	(with-temp-buffer
 	  (apply 'mew-call-process-lang
 		 (mew-pgp-get mew-prog-pgpk)
 		 nil t nil
@@ -850,7 +817,6 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 		(forward-line)
 		(setq end (point)))
 	      (write-region begin end filepath nil 'no-msg))))
-	(mew-remove-buffer buf)
 	(if error
 	    (message "Cannot extract pgp key for %s" user)
 	  (setq mew-encode-syntax
@@ -915,9 +881,7 @@ public keyring."
 	 (insert "If you do not know what TRUST and VALIDITY is,\n"
 		 "you should learn the web of trust system BEFORE\n"
 		 "using PGP to protect your privacy.\n"
-		 "**************** IMPORTANT NOTE ****************\n")
-	 ;; (let ((inhibit-quit t)) (read-char-exclusive)) ;; xxx
-	 ))
+		 "**************** IMPORTANT NOTE ****************\n")))
       (mew-delete-file mew-pgp-tmp-file))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -970,17 +934,16 @@ public keyring."
 	(message "Cannot find PGP public key's information")))))
 
 (defun mew-pgp-fetch (uri)
-  (let ((buf (generate-new-buffer mew-buffer-prefix)))
-    (message "PGP key fetching...")
-    (mew-piolet
-     mew-cs-autoconv mew-cs-autoconv
-     (setq mew-pgp-fetch-process
-	   (apply 'start-process
-		  "Mew PGP fetch" buf
-		  mew-prog-pgpkey
-		  (append mew-prog-pgpkey-arg (list uri)))))
-    (set-process-sentinel
-     mew-pgp-fetch-process 'mew-pgp-fetch-process-sentinel)))
+  (message "PGP key fetching...")
+  (mew-piolet
+   mew-cs-autoconv mew-cs-autoconv
+   (setq mew-pgp-fetch-process
+	 (apply 'start-process
+		"Mew PGP fetch"
+		(generate-new-buffer mew-buffer-prefix)
+		mew-prog-pgpkey
+		(append mew-prog-pgpkey-arg (list uri)))))
+  (set-process-sentinel mew-pgp-fetch-process 'mew-pgp-fetch-process-sentinel))
 
 (defun mew-pgp-fetch-process-kill ()
   "Kill the current process fetching PGP keys."
@@ -1000,7 +963,7 @@ public keyring."
 	       (search-forward mew-pgp-key-end nil t))
 	  (mew-mime-pgp-keys-ext (current-buffer) (point-min) (point-max))
 	(message "PGP key fetch failed")))
-    (kill-buffer buf)
+    (mew-remove-buffer buf)
     (setq mew-pgp-fetch-process nil)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -1041,7 +1004,7 @@ public keyring."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2002 Mew developing team.
+;; Copyright (C) 1994-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
