@@ -661,21 +661,17 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 	(fld (mew-summary-folder-name))
 	(msg (mew-summary-message-number2))
 	(win (selected-window))
-	(tmpbuf (generate-new-buffer mew-buffer-prefix))
 	(customize-var '(mew-refile-ctrl-multi
 			 mew-refile-guess-key-list
 			 mew-refile-guess-strip-domainpart
 			 mew-refile-guess-from-me-is-special))
 	guess)
-    (save-excursion
-      (set-buffer tmpbuf)
-      (mew-erase-buffer)
+    (with-temp-buffer
       (mew-insert-message fld msg mew-cs-autoconv
 			  mew-header-reasonable-size)
       (mew-sinfo-set-case case)
       (mew-sinfo-set-proto proto)
       (setq guess (mew-refile-guess nil t)))
-    (mew-remove-buffer tmpbuf)
     (mew-window-configure 'message)
     ;; message buffer
     (mew-elet
@@ -819,7 +815,7 @@ This is very convenient to refile all messages picked by '\\[mew-summary-search-
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2002 Mew developing team.
+;; Copyright (C) 1994-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
