@@ -271,7 +271,7 @@ Otherwise append 'mew-scan-form-header' to FORM."
 ;;;
 
 (defun mew-scan-get-piece (spec)
-  (let (func width str rightp)
+  (let (func width str rightp nopad)
     (if (stringp spec)
 	(progn
 	  (setq TOTAL (+ TOTAL (length spec))) ;; xxx length
@@ -280,7 +280,10 @@ Otherwise append 'mew-scan-form-header' to FORM."
 	  (setq width 1 func spec)
 	(setq width (nth 0 spec) func (nth 1 spec)))
       (when (and (integerp width) (symbolp func))
-	(if (= width 0) (setq width (- WIDTH TOTAL 1)))
+	(when (= width 0)
+	  (setq width (- WIDTH TOTAL 1))
+	  (unless mew-use-spc-padding
+	    (setq nopad t)))
 	(if (< width 0) (setq width (abs width) rightp t))
 	(setq TOTAL (+ TOTAL width))
 	(setq func (intern-soft
@@ -292,7 +295,7 @@ Otherwise append 'mew-scan-form-header' to FORM."
 		  (format (format "%%%ds" width) str)
 		(setq TOTAL (+ (- TOTAL width) (length str)))
 		str) ;; width may exceed.
-	    (mew-substring str width)))))))
+	    (mew-substring str width nil nopad)))))))
 
 (defun mew-scan-get-line (mew-vec WIDTH &optional VIRTUALP)
   (let* ((TOTAL 0)
@@ -608,17 +611,13 @@ non-nil, only headers of messages are cacched. If executed with
 		  (min (point-min))
 		  (max (point-max))
 		  (beg (mew-decode-syntax-begin))
-		  (end (mew-decode-syntax-end))
-		  (tmpbuf (generate-new-buffer mew-buffer-prefix)))
-	      (set-buffer tmpbuf)
-	      (mew-erase-buffer)
-	      (mew-insert-buffer-substring cbuf min beg)
-	      (mew-insert-buffer-substring cbuf end max)
-	      (mew-frwlet
-	       mew-cs-dummy mew-cs-m17n
-	       (write-region (point-min) (point-max) cache nil 'no-msg))
-	      (set-buffer cbuf)
-	      (mew-remove-buffer tmpbuf))
+		  (end (mew-decode-syntax-end)))
+	      (with-temp-buffer
+		(mew-insert-buffer-substring cbuf min beg)
+		(mew-insert-buffer-substring cbuf end max)
+		(mew-frwlet
+		 mew-cs-dummy mew-cs-m17n
+		 (write-region (point-min) (point-max) cache nil 'no-msg))))
 	  ;; (write-region 1 1 ...) does not update the file timestamp
 	  ;; but does the directory timestamp. So, we need to delete
 	  ;; the file to update the file timestamp.
@@ -645,7 +644,7 @@ non-nil, only headers of messages are cacched. If executed with
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2002 Mew developing team.
+;; Copyright (C) 1996-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
