@@ -48,34 +48,22 @@
 
 (defconst mew-ssh-info-prefix "mew-ssh-info-")
 
-(defsubst mew-ssh-info-name (sshserver localport)
-  (format "%s/%s/%d" mew-ssh-info-prefix sshserver localport))
+(defsubst mew-ssh-info-name (sshserver server remoteport localport)
+  (format "%s:%s:%s:%s:%d"
+	  mew-ssh-info-prefix sshserver server remoteport localport))
+
+(defsubst mew-ssh-info-name-regex (sshserver server remoteport)
+  (format "^%s:%s:%s:%s" mew-ssh-info-prefix sshserver server remoteport))
 
 (defsubst mew-ssh-pnm-to-lport (pnm)
-  (if (string-match "/\\([0-9]+\\)$" pnm) (mew-match 1 pnm)))
+  (if (string-match ":\\([0-9]+\\)$" pnm) (match-string 1 pnm)))
 
 ;; user@host. port should be used here.
 ;; However, SSH does not symbolic port name "ssh" for the "-p" option
 ;; while OpenSSH does. Sigh...
 (defsubst mew-ssh-passtag (name)
-  (if (string-match (format "^%s/[^/]+/" mew-ssh-info-prefix) name)
-      (mew-match 0 name)))
-
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;
-;;; Port DB
-;;;
-
-(defvar mew-port-db
-  '(("pop3" . "110")
-    ("nntp" . "119")
-    ("smtp" . "25")))
-
-(defun mew-serv-to-port (serv)
-  (if (string-match "^[0-9]+$" serv)
-      serv
-    (or (cdr (assoc serv mew-port-db)) "0")))
-
+  (if (string-match (format "^%s:[^:]+:" mew-ssh-info-prefix) name)
+      (match-string 0 name)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -84,67 +72,81 @@
 
 (defun mew-open-ssh-stream (server serv sshserver)
   "Open SSH stream for SERVER's SERV via SSHSERVER.
-This function returns a process when a SSH connection is created
+This function returns a process when an SSH connection is created
 successfully. A local port number can be obtained the process name
-after '/'. "
+after ':'. "
   (cond
    ((not (and (stringp server) (stringp serv) (stringp sshserver)))
     ())
    ((not (mew-which-exec mew-prog-ssh))
     ())
    (t
-    (let ((remoteport (mew-serv-to-port serv))
-	  (localport (+ 8000 (% (mew-random) 4000)))
-	  (process-connection-type mew-connection-type2)
-	  (i 0) (N mew-ssh-process-exec-cnt)
-	  name pnm pro status)
-      (message "Connecting to the SSH server...")
-      (catch 'loop
-	(while (< i N)
-	  (setq name (mew-ssh-info-name sshserver localport))
-	  (setq pro (apply
-		     (function start-process)
-		     name nil
-		     mew-prog-ssh "-x" "-v"
-		     "-o" (concat 
-			   (if (= mew-ssh-ver 2)
-			       "NumberOfPasswordPrompts " ;; OpenSSH style
-			     "NumberOfPasswordPrompts=")  ;; SSH style
-			   (int-to-string mew-ssh-number-of-password-prompts))
-		     (format "-L%d:%s:%s" localport server remoteport)
-		     sshserver
-		     mew-prog-ssh-arg))
-	  ;; An error would occur. So, let's exit in the case.
-	  (mew-timing)
-	  (cond
-	   ((not (processp pro))
+    (let* ((remoteport (mew-serv-to-port serv))
+	   (localport (+ 8000 (% (mew-random) 4000)))
+	   (process-connection-type mew-connection-type2)
+	   (i 0) (N mew-ssh-process-exec-cnt)
+	   (pros (process-list))
+	   (regex (mew-ssh-info-name-regex sshserver server remoteport))
+	   buf name pnm pro status)
+      (catch 'find
+	(while pros
+	  (when (string-match regex (process-name (car pros)))
+	    (if (memq (process-status (car pros)) '(run))
+		(setq pro (car pros))
+	      (delete-process (car pros)))
+	    (throw 'find nil))
+	  (setq pros (cdr pros))))
+      (if pro
+	  pro
+	(message "Connecting to the SSH server...")
+	(setq pro nil)
+	(setq buf (generate-new-buffer (concat mew-buffer-prefix "ssh")))
+	(catch 'loop
+	  (while (< i N)
+	    (setq name (mew-ssh-info-name sshserver server remoteport localport))
+	    (setq pro
+		  (apply 'start-process
+			 name buf
+			 mew-prog-ssh "-x" "-v"
+			 "-o" (concat 
+			       (if (= mew-ssh-ver 2)
+				   "NumberOfPasswordPrompts " ;; OpenSSH style
+				 "NumberOfPasswordPrompts=")  ;; SSH style
+			       (int-to-string mew-ssh-number-of-password-prompts))
+			 (format "-L%d:%s:%s" localport server remoteport)
+			 sshserver
+			 mew-prog-ssh-arg))
+	    ;; An error would occur. So, let's exit in the case.
+	    (mew-timing)
+	    (cond
+	     ((not (processp pro))
+	      (message "Connecting to the SSH server...FAILED")
+	      (throw 'loop nil))
+	     ((not (memq (process-status pro) '(run)))
+	      (delete-process pro)
+	      (message "Connecting to the SSH server...FAILED")
+	      (throw 'loop nil)))
+	    ;; ssh is now running.
+	    (process-kill-without-query pro)
+	    (setq pnm (process-name pro))
+	    (mew-info-clean-up pnm)
+	    (mew-ssh-set-try pnm 0)
+	    (mew-set-process-cs pro mew-cs-text-for-read mew-cs-text-for-write)
+	    (set-process-filter pro 'mew-ssh-filter)
+	    (set-process-sentinel pro 'mew-ssh-sentinel)
+	    (mew-rendezvous (null (mew-ssh-get-status pnm)))
+	    (setq status (mew-ssh-get-status pnm))
+	    (cond
+	     ((eq status t)
+	      (throw 'loop pro)) ;; return value
+	     ((not (eq status 'bound))
+	      (message "Connecting to the SSH server...FAILED")
+	      (throw 'loop nil))) ;; return value
+	    ;; 'bound
+	    (setq localport (1+ localport))
+	    (setq i (1+ i))
 	    (message "Connecting to the SSH server...FAILED")
-	    (throw 'loop nil))
-	   ((not (memq (process-status pro) '(run)))
-	    (delete-process pro)
-	    (message "Connecting to the SSH server...FAILED")
-	    (throw 'loop nil)))
-	  ;; ssh is now running.
-	  (process-kill-without-query pro)
-	  (setq pnm (process-name pro))
-	  (mew-info-clean-up pnm)
-	  (mew-ssh-set-try pnm 0)
-	  (mew-set-process-cs pro mew-cs-text-for-read mew-cs-text-for-write)
-	  (set-process-filter pro 'mew-ssh-filter)
-	  (set-process-sentinel pro 'mew-ssh-sentinel)
-	  (mew-rendezvous (null (mew-ssh-get-status pnm)))
-	  (setq status (mew-ssh-get-status pnm))
-	  (cond
-	   ((eq status t)
-	    (throw 'loop pro)) ;; return value
-	   ((not (eq status 'bound))
-	    (message "Connecting to the SSH server...FAILED")
-	    (throw 'loop nil))) ;; return value
-	  ;; 'bound
-	  (setq localport (1+ localport))
-	  (setq i (1+ i))
-	  (message "Connecting to the SSH server...FAILED")
-	  nil)))))) ;; return value
+	    nil))))))) ;; return value
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -190,8 +192,9 @@ after '/'. "
 
 (defun mew-ssh-sentinel (process event)
   (let ((pnm (process-name process)))
-    (if (null (mew-ssh-get-status pnm))
-	(mew-ssh-set-status pnm 'exit))))
+    (unless (mew-ssh-get-status pnm)
+      (mew-ssh-set-status pnm 'exit))
+    (mew-remove-buffer (process-buffer process))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -201,30 +204,26 @@ after '/'. "
 (defun mew-ssh-setup ()
   (if (not (mew-which-exec mew-prog-ssh))
       (setq mew-ssh-ver nil)
-    (let ((buf (generate-new-buffer mew-buffer-prefix)))
-      (save-excursion
-	(set-buffer buf)
-	(mew-erase-buffer)
-	(call-process mew-prog-ssh nil t nil "-V")
-	(goto-char (point-min))
-	(cond
-	 ((looking-at "SSH Version 1")
-	  (setq mew-ssh-ver 0))
-	 ((looking-at (concat mew-prog-ssh ": SSH Version 2"))
-	  (setq mew-ssh-ver 1))
-	 ((looking-at (concat mew-prog-ssh ": SSH Secure Shell 2"))
-	  (setq mew-ssh-ver 1))
-	 ((looking-at "\\(SSH Version \\)?\\(OpenSSH\\|NetBSD\\)")
-	  (setq mew-ssh-ver 2))
-	 (t
-	  (setq mew-ssh-ver nil))))
-      (mew-remove-buffer buf))))
+    (with-temp-buffer
+      (call-process mew-prog-ssh nil t nil "-V")
+      (goto-char (point-min))
+      (cond
+       ((looking-at "SSH Version 1")
+	(setq mew-ssh-ver 0))
+       ((looking-at (concat mew-prog-ssh ": SSH Version 2"))
+	(setq mew-ssh-ver 1))
+       ((looking-at (concat mew-prog-ssh ": SSH Secure Shell [23]"))
+	(setq mew-ssh-ver 1))
+       ((looking-at "\\(SSH Version \\)?\\(OpenSSH\\|NetBSD\\|Sun_SSH\\)")
+	(setq mew-ssh-ver 2))
+       (t
+	(setq mew-ssh-ver nil))))))
 
 (provide 'mew-ssh)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2002 Mew developing team.
+;; Copyright (C) 1999-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
