@@ -2,7 +2,7 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Mar 23, 1994
-;; Revised: Dec  2, 2002
+;; Revised: Feb 25, 2003
 
 ;;; Commentary:
 
@@ -10,33 +10,7 @@
 ;;	ftp://ftp.Mew.org/pub/Mew/mew-current.tar.gz
 ;;	http://www.Mew.org/
 ;;
-;; Minimum setup:
-;;	(autoload 'mew "mew" nil t)
-;;	(autoload 'mew-send "mew" nil t)
-;;      ;; (setq mew-name "your name") ;; (user-full-name)
-;;      ;; (setq mew-user "user name of e-mail address") ;; (user-login-name)
-;;	(setq mew-mail-domain "domain of e-mail address")
-;;      ;; (setq mew-pop-user "your POP account")  ;; (user-login-name)
-;;	(setq mew-pop-server "your POP server")    ;; if not localhost
-;;	(setq mew-smtp-server "your SMTP server")  ;; if not localhost
-;;	(setq mew-icon-directory "icon directory") ;; if using XEmacs/Emacs 21
-;;      ;; See also mew-config-alist for advanced use
-;;
-;; Optional setup (Read Mail menu for Emacs 21):
-;;      (if (boundp 'read-mail-command)
-;;          (setq read-mail-command 'mew))
-;;
-;; Optional setup (e.g. C-xm for sending a message):
-;;	(autoload 'mew-user-agent-compose "mew" nil t)
-;;	(if (boundp 'mail-user-agent)
-;;	    (setq mail-user-agent 'mew-user-agent))
-;;	(if (fboundp 'define-mail-user-agent)
-;;	    (define-mail-user-agent
-;;	      'mew-user-agent
-;;	      'mew-user-agent-compose
-;;	      'mew-draft-send-message
-;;	      'mew-draft-kill
-;;	      'mew-send-hook))
+;; See info for configuring a site file/.emacs/.mew.el.
 
 ;;; Code:
 
@@ -45,7 +19,7 @@
 ;;; Mew version
 ;;;
 
-(defconst mew-version-number "2.3"
+(defconst mew-version-number "3.2"
   "Version number for this version of Mew.")
 (defconst mew-version (format "Mew version %s" mew-version-number)
   "Version string for this version of Mew.")
@@ -56,16 +30,16 @@
 (require 'mew-vars)
 (require 'mew-vars2)
 (cond
- ((memq system-type '(OS/2 emx))
-  (require 'mew-os2))
  ((eq system-type 'windows-nt)
   (require 'mew-win32))
+ ((eq system-type 'darwin)
+  (require 'mew-darwin))
  (t
   (require 'mew-unix)))
 
 (eval-when-compile
-  (if (not (fboundp 'mew-scan-setup))
-      (require 'mew-scan))
+  (unless (fboundp 'mew-scan-setup)
+    (require 'mew-scan))
   (mew-scan-setup))
 
 (defun mew-version-show ()
@@ -95,18 +69,37 @@
 
 ;;;###autoload
 (defun mew (&optional arg)
-  "Execute Mew. If 'mew-auto-get' is 't', messages stored in your
-mailbox are fetched to the +inbox folder and messages in the +inbox
-folder are listed up in Summary mode. If 'mew-auto-get' is 'nil', list
-up messages in the inbox folder. If '\\[universal-argument]' is specified, perform this
-function thinking that 'mew-auto-get' is reversed."
+  "Execute Mew first unless Mew is running. And retrieve arrived
+messages or just visit to the default folder.
+
+'proto' is determined by 'mew-proto' and 'mew-input-case'.  
+
+If 'proto' is '+' (ie a local folder), a mailbox is determined
+according to 'mew-mailbox-type'. Otherwise (ie a remote folder), an
+appropriate protocol to retrieve messages is chosen according to
+'proto'.
+
+If 'mew-auto-get' is 't', arrived messages are asynchronously fetched
+and listed up in Summary mode.
+
+'mew-auto-get' is 'nil', just visit to the folder determined by
+'proto'.
+
+When executed with '\\[universal-argument]', 'mew-auto-get' is
+considered reversed."
   (interactive "P")
   (mew-window-push)
-  (if (null mew-init-p) (mew-init))
-  (let ((auto (if arg (not mew-auto-get) mew-auto-get)))
+  (unless mew-init-p (mew-init))
+  (let* ((auto (if arg (not mew-auto-get) mew-auto-get))
+	 (case mew-case-input)
+	 (proto (mew-proto case))
+	 inbox)
     (if auto
-	(mew-summary-retrieve)
-      (mew-summary-goto-folder 'goend (mew-inbox-folder mew-case-input)))
+	(mew-summary-scan-boot proto case)
+      ;; see also mew-summary-retrieve
+      (setq inbox (mew-proto-inbox-folder proto case))
+      (setq inbox (mew-folder-case-folder case inbox))
+      (mew-summary-visit-folder inbox 'goend 'no-ls))
     (setq mew-inbox-window (current-window-configuration))))
 
 ;;;###autoload
@@ -115,14 +108,14 @@ function thinking that 'mew-auto-get' is reversed."
 function."
   (interactive)
   (mew-current-set-window-config)
-  (if (null mew-init-p) (mew-init))
+  (unless mew-init-p (mew-init))
   (mew-summary-send to cc subject))
 
 ;;;###autoload
 (defun mew-user-agent-compose (&optional to subject other-headers continue
                                              switch-function yank-action
                                              send-actions)
-  "Set up mail composition draft with Mew.
+  "Set up message composition draft with Mew.
 This is 'mail-user-agent' entry point to Mew.
 
 The optional arguments TO and SUBJECT specify recipients and the
@@ -135,7 +128,7 @@ HEADER and VALUE are strings.
 A Draft buffer is prepared according to SWITCH-FUNCTION.
 
 CONTINUE, YANK-ACTION and SEND-ACTIONS are ignored."
-  (if (null mew-init-p) (mew-init))
+  (unless mew-init-p (mew-init))
   (let* ((draft (mew-folder-new-message mew-draft-folder))
 	 (attachdir (mew-attachdir draft)))
     (mew-current-set-window-config)
@@ -153,10 +146,10 @@ CONTINUE, YANK-ACTION and SEND-ACTIONS are ignored."
 ;;;
 
 (defun mew-init ()
-  (let ((buf (generate-new-buffer mew-buffer-prefix)))
+  (with-temp-buffer
     (run-hooks 'mew-env-hook)
-    (load mew-rc-file 'no-err)
-    (switch-to-buffer buf)
+    (load mew-rc-file 'no-err 'no-msg)
+    (switch-to-buffer (current-buffer))
     (mew-window-configure '(1 0)) ;; Using mew-mode-name-message
     (mew-hello)
     (message "Setting up Mew world...")
@@ -166,8 +159,7 @@ CONTINUE, YANK-ACTION and SEND-ACTIONS are ignored."
     (mew-passwd-setup)
     (mew-highlight-timer-setup)
     (setq mew-init-p t)
-    (message "Setting up Mew world...done")
-    (mew-remove-buffer buf)))
+    (message "Setting up Mew world...done")))
 
 (defun mew-set-environment (&optional no-dir)
   (let (error-message)
@@ -183,7 +175,8 @@ CONTINUE, YANK-ACTION and SEND-ACTIONS are ignored."
 	  (or no-dir (mew-temp-dir-init))
 	  (mew-mark-init)
 	  (mew-config-init)
-	  (mew-rotate-log-files mew-smtp-log-file))
+	  (mew-rotate-log-files mew-smtp-log-file)
+	  (mew-rotate-log-files mew-nntp-log-file))
       (error
        (set-buffer (generate-new-buffer mew-buffer-debug))
        (goto-char (point-max))
@@ -210,7 +203,7 @@ set mew-touch-folder-p to t"
 		 (equal (nth 0 curtime) (nth 0 time1)))
 	    (sleep-for 1))
 	(write-region "touched by Mew.(test)" nil file nil 'no-msg)
-	(if (file-exists-p file) (delete-file file))
+	(mew-delete-file file)
 	(setq time2 (mew-file-get-time dir))
 	(if (equal time1 time2)
 	    ;; this system cannot update directory timestamp.
@@ -221,32 +214,59 @@ set mew-touch-folder-p to t"
 ;;; Status update
 ;;;
 
+(defun mew-folder-init (folders)
+  (let (folder dir)
+    (while folders
+      (setq folder (mew-canonicalize-folder (car folders)))
+      (setq folders (cdr folders))
+      (setq dir (mew-expand-folder folder))
+      (unless (file-exists-p dir)
+	(mew-make-directory dir)
+	(mew-local-folder-insert folder)
+	(message "%s was created" dir))
+      (setq dir (file-chase-links dir))
+      (if (file-exists-p dir)
+	  (if (/= mew-folder-mode (mew-file-get-mode dir))
+	      (set-file-modes dir mew-folder-mode))))))
+
 (defun mew-status-update (arg)
-  "Read Addrbook and update its information. If executed with '\\[universal-argument]',
-information of folders is also updated in addition to that of
-Addrbook. The default value is 't'."
+  "Read Addrbook and update its information. 
+If executed with '\\[universal-argument]', information about local folders is 
+also updated in addition to that of Addrbook. 
+If executed with '1', information about local folders is updated.
+If executed with '2', information about newsgroups is updated.
+If executed with '3', information about IMAP folders is updated. "
   (interactive "P")
   (message "Updating status...")
-  (if (interactive-p) (mew-set-environment 'no-dir))
-  ;; These two must be before mew-folder-setup
-  (mew-config-setup)
-  (mew-regex-setup)
-  (if arg (mew-folder-setup (interactive-p)))
-  (mew-folder-init mew-basic-folders)
-  (mew-folder-init mew-inbox-folders)
-  (mew-folder-init mew-queue-folders)
-  (mew-folder-init mew-mdrop-folders)
-  (mew-touch-folder-check)
-  (mew-refile-setup)
-  (mew-addrbook-setup)
-  (mew-scan-setup)
-  (mew-pgp-setup)
-  (mew-ssh-setup)
-  (mew-pop-setup)
-  (mew-thread-setup)
-  (mew-theme-setup)
-  (mew-pop-biff-setup)
-  (mew-ct-setup)
+  (cond
+   ((eq arg 1)
+    (mew-local-update (interactive-p)))
+   ((eq arg 2)
+    (mew-nntp-update))
+   ((eq arg 3)
+    (mew-imap-update))
+   (t
+    (if (interactive-p) (mew-set-environment 'no-dir))
+    ;; These two must be before mew-local-update
+    (mew-config-setup)
+    (mew-regex-setup)
+    (if arg (mew-local-update (interactive-p))) ;; arg == '(4)
+    (mew-folder-init mew-basic-folders)
+    (mew-folder-init mew-inbox-folders)
+    (mew-folder-init mew-queue-folders)
+    (mew-folder-init mew-postq-folders)
+    (mew-touch-folder-check)
+    (mew-refile-setup)
+    (mew-addrbook-setup)
+    (mew-scan-setup)
+    (mew-pgp-setup)
+    (mew-ssh-setup)
+    (mew-ssl-setup)
+    (mew-net-setup)
+    (mew-thread-setup)
+    (mew-theme-setup)
+    (mew-biff-setup)
+    (mew-ct-setup)))
   (message "Updating status...done"))
 
 (defvar mew-mime-content-type-list nil
@@ -261,219 +281,6 @@ Addrbook. The default value is 't'."
 	  (setq mew-mime-content-type-list
 		(cons (capitalize ct) mew-mime-content-type-list))))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;
-;;; Folders
-;;;
-
-(defun mew-folder-init (folders)
-  (let (folder dir)
-    (while folders
-      (setq folder (mew-canonicalize-folder (car folders)))
-      (setq folders (cdr folders))
-      (setq dir (mew-expand-folder folder))
-      (unless (file-exists-p dir)
-	(mew-make-directory dir)
-	(mew-folder-insert folder)
-	(message "%s was created" dir))
-      (setq dir (file-chase-links dir))
-      (if (file-exists-p dir)
-	  (if (/= mew-folder-mode (mew-file-get-mode dir))
-	      (set-file-modes dir mew-folder-mode))))))
-
-(defvar mew-folder-list nil)
-(defvar mew-folder-alist nil)
-
-(defsubst mew-folder-make-alist (list)
-  (mapcar (function mew-folder-pair) list))
-
-(defun mew-folder-setup (&optional interactivep)
-  (interactive)
-  (unless interactivep
-    (add-hook 'kill-emacs-hook (function mew-folder-clean-up))
-    (setq mew-folder-list (mew-lisp-load mew-folder-list-file))
-    (setq mew-folder-alist (mew-lisp-load mew-folder-alist-file)))
-  (when (or interactivep (null mew-folder-list))
-    (let ((mail-dirs (mew-dir-list mew-mail-path))
-	  (news-dirs (mew-dir-list mew-news-path)))
-      (setq mew-folder-list (mew-folder-make-list mail-dirs "+"))
-      (setq mew-folder-list (nconc mew-folder-list
-				   (mew-folder-make-list news-dirs "=")))))
-  (when (or interactivep (null mew-folder-alist))
-    (setq mew-folder-alist (mew-folder-make-alist mew-folder-list)))
-  (when interactivep
-    (mew-lisp-save mew-folder-list-file mew-folder-list)
-    (mew-lisp-save mew-folder-alist-file mew-folder-alist)))
-
-(defun mew-folder-clean-up ()
-  (remove-hook 'kill-emacs-hook (function mew-folder-clean-up))
-  ;; ++virtual locates before +folder.
-  (let ((lst mew-folder-list)
-	(alst mew-folder-alist))
-    (while (and (car lst) (mew-folder-virtualp (car lst)))
-      (setq lst (cdr lst)))
-    (while (and (car alst) (mew-folder-virtualp (car (car alst))))
-      (setq alst (cdr alst)))
-    (mew-lisp-save mew-folder-list-file lst)
-    (mew-lisp-save mew-folder-alist-file alst))
-  (setq mew-folder-list nil)
-  (setq mew-folder-alist nil))
-
-(defun mew-folder-insert (folder)
-  "Insert FOLDER to 'mew-folder-list' and 'mew-folder-alist'.
-It is assumed that both variables contain ordered folders
-according to 'mew-folder<'. Binary search is used for speed reasons."
-  (unless (or (member folder mew-folder-list)
-	      (member (file-name-as-directory folder) mew-folder-list))
-    (let ((case-fold-search nil)
-	  (rfld (mew-folder-regex folder))
-	  (max (1- (length mew-folder-list)))
-	  (min 0) mid crr1 prv1 crr2 prv2)
-      (while (> (- max min) 20) ;; 20 is enough?
-	(setq mid (/ (+ min max) 2))
-	(if (mew-folder< (nth mid mew-folder-list) folder rfld)
-	    (setq min mid)
-	  (setq max mid)))
-      (setq crr1 (nthcdr min mew-folder-list))
-      (setq crr2 (nthcdr min mew-folder-alist))
-      (while (and crr1 (mew-folder< (car crr1) folder rfld))
-	(setq prv1 crr1)
-	(setq crr1 (cdr crr1))
-	(setq prv2 crr2)
-	(setq crr2 (cdr crr2)))
-      (if prv1
-	  (setcdr prv1 (cons folder crr1))
-	(setq mew-folder-list (cons folder crr1))) ;; xxx +foo or +foo/?
-      (if prv2
-	  (setcdr prv2 (cons (mew-folder-pair folder) crr2))
-	;; xxx
-	(setq mew-folder-alist (cons (mew-folder-pair folder) crr2))))))
-
-(defsubst mew-folder< (fld1 fld2 rfld)
-  "Folder ordering: Example is as follows:
-	Mail/draft
-	Mail/from/kazu
-	Mail/from/
-"
-  (cond
-   ((string-match (mew-folder-regex fld1) fld2) nil)
-   ((string-match rfld fld1) t)
-   (t (string< fld1 fld2))))
-
-(defun mew-folder-delete (folder)
-  ;; used to delete +virtual only. 
-  ;; So, this does not take care of +foo/
-  (setq mew-folder-list (delete folder mew-folder-list))
-  (setq mew-folder-alist
-	;; delq is right. no need to use delete.
-	(delq (assoc folder mew-folder-alist) mew-folder-alist)))
-
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;
-;;; Listing folders
-;;; 
-
-(defsubst mew-dir-list (dir)
-  (if (file-directory-p (expand-file-name dir))
-      (funcall mew-dir-list-function dir)
-    ()))
-
-(defun mew-dir-list-with-link-count (dir)
-  "Collecting a directory list under DIR.
-Subdirectories are expressed by a list.
-This function uses two techniques for speed up.
-
-One is to gather candidates of directory by matching
-'mew-regex-folder-candidate'. Its default is [^.0-9]. So, typical
-messages whose name is numeric are not gathered. This makes it faster
-to check wether or not each candidate is a directory in 'while' loop.
-
-The other is to see if the link count of a directory is 2. If so, the
-directory does not have subdirectories. So, it is not necessary to
-trace down. This technique can be used on UNIX variants."
-  (let ((default-directory (expand-file-name dir default-directory))
-	file dirent dirs ent subdirs)
-    (setq dirent (directory-files "." nil mew-regex-folder-candidate))
-    ;; MUST sort
-    (while dirent
-      (setq file (car dirent))
-      (setq ent (mew-file-chase-links file))
-      (setq dirent (cdr dirent))
-      (when (file-directory-p ent)
-	(setq dirs (cons file dirs))
-	(when (and (mew-file-get-links ent) ;; necessary
-		   (/= (mew-file-get-links ent) 2))
-	  (setq subdirs (mew-dir-list-with-link-count file))
-	  (if subdirs (setq dirs (cons subdirs dirs))))))
-    (nreverse dirs)))
-
-(defun mew-dir-list-without-link-count (dir)
-  "Collecting a directory list under DIR.
-Subdirectories are expressed by a list.
-This function uses one technique for speed up.
-
-It is to gather candidates of directory by matching
-'mew-regex-folder-candidate'. Its default is [^.0-9]. So, typical
-messages whose name is numeric are not gathered. This makes it faster
-to check wether or not each candidate is a directory in 'while' loop."
-  (let ((default-directory (expand-file-name dir default-directory))
-	file dirent dirs ent subdirs)
-    (setq dirent (directory-files "." nil mew-regex-folder-candidate))
-    ;; MUST sort
-    (while dirent
-      (setq file (car dirent))
-      (setq ent (mew-file-chase-links file))
-      (setq dirent (cdr dirent))
-      (when (file-directory-p ent)
-	(setq dirs (cons file dirs))
-	(setq subdirs (mew-dir-list-without-link-count file))
-	(if subdirs (setq dirs (cons subdirs dirs)))))
-    (nreverse dirs)))
-
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;
-;;; Folder lists
-;;;
-
-(defsubst mew-folder-make-list (dirs prefix)
-  (nreverse (mew-folder-make-list2 dirs prefix)))
-
-(defun mew-folder-make-list2 (dirs prefix)
-  (let (fldpfx dir ret ent)
-    (if (= (length prefix) 1)
-	(setq fldpfx prefix)
-      (setq fldpfx (file-name-as-directory prefix)))
-    (while dirs
-      (setq dir (car dirs))
-      (setq dirs (cdr dirs))
-      (setq ent (concat fldpfx dir))
-      (cond
-       ((consp (car dirs)) ;; not listp because nil is a list.
-	(cond
-	 ((or (equal mew-attach-folder ent) (equal mew-draft-folder ent))
-	  (setq ret (cons ent ret))
-	  (setq dirs (cdr dirs))) ;; skip subfolder
-	 (t
-	  (setq ret (nconc (mew-folder-make-list2 (car dirs) ent) ret))
-	  (setq ret (cons (file-name-as-directory ent) ret))
-	  (setq dirs (cdr dirs)))))
-       (t
-	(setq ret (cons ent ret)))))
-    ret))
-
-(defun mew-folder-pair (folder)
-  (let* ((dir (directory-file-name (mew-folder-to-dir folder)))
-	 ;; foo/bar  -> foo/bar
-	 ;; foo/bar/ -> foo/bar
-	 (subdir (file-name-nondirectory dir)))
-	 ;; foo/bar -> bar 
-	 ;; foo -> foo
-    (if (or (mew-folder-virtualp folder)
-	    (mew-folder-local-newsp folder)
-	    (string-match mew-regex-ignore-folders folder))
-	(list folder nil)
-      (list folder subdir))))
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Current status
@@ -509,8 +316,8 @@ to check wether or not each candidate is a directory in 'while' loop."
 
 (defsubst mew-current-get-window-config ()
   (let ((win (mew-current-get-window (mew-frame-id))))
-    (if (not (window-configuration-p win))
-	(setq win mew-inbox-window))
+    (unless (window-configuration-p win)
+      (setq win mew-inbox-window))
     (if win (set-window-configuration win))
     (mew-current-set-window (mew-frame-id) nil)
     (mew-summary-toolbar-update)
@@ -544,6 +351,24 @@ to check wether or not each candidate is a directory in 'while' loop."
 ;;;
 ;;; Window configuration
 ;;;
+(defun mew-delete-other-window ()
+  (unless (one-window-p)
+    (let ((owin (selected-window))
+	  wins ret)
+      (walk-windows
+       (lambda (win)
+	 (set-buffer (window-buffer win))
+	 (unless (or (eq owin win)
+		     (string-match "^mew-" (symbol-name major-mode)))
+	   (setq wins (cons win wins))))
+       nil)
+      (while wins
+	(unless (one-window-p)
+	  (setq ret t)
+	  (delete-window (car wins)))
+	(setq wins (cdr wins)))
+      (select-window owin)
+      ret)))
 
 (defun mew-window-configure (action)
   "Configure windows accroding to ACTION.
@@ -567,11 +392,15 @@ the lower window is not zero, switch to the buffer."
 	 (height nil) (winsum nil) (sum-height 0) (msg-height 0))
     (setq height (+ (if obufwin (window-height obufwin) 0)
 		    (if msgwin  (window-height msgwin)  0)))
-    (when (or mew-use-full-window
-	      (<= height (* 2 window-min-height)))
+    (cond
+     ((<= height (* 2 window-min-height))
       ;; Delete other windows and use full emacs window.
       (delete-other-windows)
       (setq height (window-height (selected-window))))
+     ((and mew-use-full-window (mew-delete-other-window))
+      ;; delete windows all but Mew's one.
+      (setq height (+ (if obufwin (window-height obufwin) 0)
+		      (if msgwin  (window-height msgwin)  0)))))
     ;;
     (if (get-buffer msgbuf)
 	(delete-windows-on msgbuf)
@@ -582,15 +411,14 @@ the lower window is not zero, switch to the buffer."
 	(mew-summary-toolbar-update)
 	(mew-message-mode)))
     ;;
-    (setq winsum (apply (function +) windows))
-    (if (not (zerop (nth 0 windows)))
-	(setq sum-height (max window-min-height
-			     (/ (* height (nth 0 windows)) winsum))))
+    (setq winsum (apply '+ windows))
+    (unless (zerop (nth 0 windows))
+      (setq sum-height (max window-min-height
+			    (/ (* height (nth 0 windows)) winsum))))
     (if (and (eq action 'message) (= (% sum-height 2) 1)) 
 	(setq sum-height (1+ sum-height)))
-    (if (not (zerop (nth 1 windows)))
-	(setq msg-height (max window-min-height
-			     (- height sum-height))))
+    (unless (zerop (nth 1 windows))
+      (setq msg-height (max window-min-height (- height sum-height))))
     (setq height (+ sum-height msg-height))
     ;;
     (unless (zerop msg-height)
@@ -603,19 +431,35 @@ the lower window is not zero, switch to the buffer."
 ;;; Message buffer
 ;;;
 
+(defun mew-window-number ()
+  (let ((x (car (mew-window-edges (selected-window))))
+	(i 1))
+    (walk-windows
+     (lambda (win)
+       (when (save-excursion
+	       (set-buffer (window-buffer win))
+	       (mew-summary-or-virtual-p))
+	 (if (< (car (mew-window-edges win)) x)
+	     (setq i (1+ i)))))
+     'nominibuf)
+    i))
+
 (defun mew-buffer-message ()
   (let* ((me (selected-frame))
 	 (frames (frame-list))
 	 (len (length frames))
+	 (n (mew-window-number))
 	 (i 0))
     (catch 'loop
       (while frames
-      (if (equal me (car frames))
-	  (throw 'loop i))
-      (setq i (1+ i))
-      (setq frames (cdr frames))))
+	(if (equal me (car frames))
+	    (throw 'loop i))
+	(setq i (1+ i))
+	(setq frames (cdr frames))))
     (setq i (- len i 1))
-    (format "%s%d" mew-buffer-message i)))
+    (if (= n 1)
+	(format "%s%d" mew-buffer-message i)
+      (format "%s%d<%d>" mew-buffer-message i n))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -628,8 +472,7 @@ the lower window is not zero, switch to the buffer."
   (setq mew-buffers nil))
 
 (defun mew-buffers-setup (folder)
-  (if (not (member folder mew-buffers))
-      (setq mew-buffers (cons folder mew-buffers))))
+  (mew-addq mew-buffers folder))
 
 (defun mew-buffers-bury ()
   (let ((buffers mew-buffers))
@@ -660,12 +503,12 @@ for privacy/speed reasons. "
   (mew-make-directory mew-temp-dir)
   (set-file-modes mew-temp-dir mew-folder-mode)
   (setq mew-temp-file (expand-file-name "mew" mew-temp-dir))
-  (add-hook 'kill-emacs-hook (function mew-temp-dir-clean-up)))
+  (add-hook 'kill-emacs-hook 'mew-temp-dir-clean-up))
 
 (defun mew-temp-dir-clean-up ()
   "A function to remove Mew's temporary directory recursively. 
 It is typically called by kill-emacs-hook."
-  (remove-hook 'kill-emacs-hook (function mew-temp-dir-clean-up))
+  (remove-hook 'kill-emacs-hook 'mew-temp-dir-clean-up)
   (if (and mew-temp-dir (file-exists-p mew-temp-dir))
       (mew-delete-directory-recursively mew-temp-dir))
   (setq mew-temp-dir nil)
@@ -680,6 +523,7 @@ It is typically called by kill-emacs-hook."
 (defvar mew-regex-msg-or-part nil)
 (defvar mew-regex-msg-mark nil)
 (defvar mew-regex-msg-review nil)
+(defvar mew-regex-msg-valid-review nil)
 (defvar mew-regex-msg-delete nil)
 (defvar mew-regex-attach-beg nil)
 (defvar mew-regex-attach-end nil)
@@ -689,11 +533,11 @@ It is typically called by kill-emacs-hook."
 (defsubst mew-mark-regex (mark)
   (concat mew-regex-msg (regexp-quote (char-to-string mark))))
 
+(defsubst mew-mark-valid-regex (mark)
+  (concat mew-regex-msg-valid (regexp-quote (char-to-string mark))))
+
 (defsubst mew-mark-list-regex (mark-list)
-  (concat mew-regex-msg
-	  "["
-	  (mapconcat (function char-to-string) mark-list "")
-	  "]"))
+  (concat mew-regex-msg "[" (mapconcat 'char-to-string mark-list "") "]"))
 
 (defun mew-regex-setup ()
   (setq mew-eoh (format "^\\(%s\\|\\)$" (regexp-quote mew-header-separator)))
@@ -701,6 +545,7 @@ It is typically called by kill-emacs-hook."
   (setq mew-regex-msg-or-part (concat mew-regex-msg-show "\\|" mew-regex-part))
   (setq mew-regex-msg-mark (concat mew-regex-msg mew-regex-mark))
   (setq mew-regex-msg-review (mew-mark-regex mew-mark-review))
+  (setq mew-regex-msg-valid-review (mew-mark-valid-regex mew-mark-review))
   (setq mew-regex-msg-delete (mew-mark-regex mew-mark-delete))
   (setq mew-regex-attach-beg
 	(concat "^" mew-draft-attach-boundary-beg "$"))
@@ -709,17 +554,23 @@ It is typically called by kill-emacs-hook."
   (setq mew-regex-my-address-list (mew-get-my-address-regex-list))
   (setq mew-regex-ignore-folders
 	(mapconcat
-	 (function mew-folder-regex)
+	 'mew-folder-regex
 	 (mew-uniq-list
 	  (append
 	   mew-basic-folders
 	   mew-inbox-folders
 	   mew-queue-folders
-	   mew-mdrop-folders
+	   mew-postq-folders
 	   (list
-	    mew-folders-default-folder
+	    mew-friend-folder
 	    mew-attach-folder)))
-	 "\\|")))
+	 "\\|"))
+  (unless mew-range-list
+    (setq mew-range-list
+	  `((,mew-queue-folders ,mew-range-str-all)
+	    (, mew-postq-folders ,mew-range-str-all)
+	    ((,mew-draft-folder) ,mew-range-str-all)
+	    (t ,mew-range-str-update)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -728,7 +579,7 @@ It is typically called by kill-emacs-hook."
 
 (defun mew-theme-setup ()
   (interactive)
-  (if mew-theme-file (load mew-theme-file 'no-err))
+  (if mew-theme-file (load mew-theme-file 'no-err 'no-msg))
   (when mew-gemacs-p
     (put-text-property 0 (length mew-end-of-message-string)
 		       'face 'mew-face-eof-message
@@ -757,24 +608,18 @@ It is typically called by kill-emacs-hook."
 	  (set-buffer buf)
 	  (when (mew-summary-or-virtual-p)
 	    (mew-summary-kill-subprocess 'no-msg)
-	    (setq obuf (mew-scan-buffer-name folder))
+	    (setq obuf (mew-local-buffer-name folder))
 	    ;; xxx should kill pop's buffer...
 	    (mew-remove-buffer obuf))
-	  (if (mew-virtual-p)
-	      (mew-folder-delete folder))
 	  (mew-overlay-delete-buffer)))
     (mew-remove-buffer buf)))
 
 (defun mew-buffer-clean-up (regex &optional func)
-  (let ((bufs (buffer-list))
-	buf bn)
-    (unless func (setq func (function mew-kill-buffer)))
+  (unless func (setq func 'mew-kill-buffer))
+  (let ((bufs (mew-buffer-list regex)))
     (while bufs
-      (setq buf (car bufs))
-      (setq bufs (cdr bufs))
-      (if (and (setq bn (buffer-name buf))
-	       (string-match regex bn))
-	  (funcall func buf)))))
+      (funcall func (car bufs))
+      (setq bufs (cdr bufs)))))
 
 (defsubst mew-quit-toolbar-update ()
   (mew-redraw) ;; due to mouse-face bug
@@ -787,7 +632,7 @@ Mew remain, so you can resume with buffer operations."
   (interactive)
   (mew-buffer-clean-up
    (concat "^" (regexp-quote mew-buffer-message))
-   (function mew-bury-buffer))
+   'mew-bury-buffer)
   (mew-buffers-bury)
   (mew-window-pop)
   (mew-quit-toolbar-update)
@@ -818,8 +663,8 @@ Mew remain, so you can resume with buffer operations."
     (mew-addrbook-clean-up)
     (mew-passwd-clean-up)
     (mew-highlight-timer-clean-up)
-    (mew-pop-clean-up)
-    (mew-pop-biff-clean-up)
+    (mew-net-clean-up)
+    (mew-biff-clean-up)
     ;;
     (mew-window-pop)
     (mew-window-clean-up)
@@ -833,6 +678,7 @@ Mew remain, so you can resume with buffer operations."
 ;;; Load Mew libraries
 ;;;
 
+(require 'mew-local)
 (require 'mew-addrbook)
 (require 'mew-complete)
 (require 'mew-minibuf)
@@ -842,6 +688,7 @@ Mew remain, so you can resume with buffer operations."
 (require 'mew-edit)
 (require 'mew-mime)
 (require 'mew-mark)
+(require 'mew-exec)
 (require 'mew-header)
 (require 'mew-pgp)
 (require 'mew-smime)
@@ -850,6 +697,9 @@ Mew remain, so you can resume with buffer operations."
 (require 'mew-scan)
 (require 'mew-pick)
 (require 'mew-summary)
+(require 'mew-summary2)
+(require 'mew-summary3)
+(require 'mew-summary4)
 (require 'mew-virtual)
 (require 'mew-thread)
 (require 'mew-message)
@@ -861,16 +711,20 @@ Mew remain, so you can resume with buffer operations."
 (require 'mew-fib)
 (require 'mew-sort)
 (require 'mew-highlight)
+(require 'mew-net)
+(require 'mew-ssh)
+(require 'mew-ssl)
 (require 'mew-smtp)
 (require 'mew-pop)
-(require 'mew-ssh)
 (require 'mew-nntp)
+(require 'mew-nntp2)
+(require 'mew-imap)
 (require 'mew-config)
 (require 'mew-auth)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2002 Mew developing team.
+;; Copyright (C) 1994-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
